@@ -1,40 +1,39 @@
 /*
  * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#include <libxfs.h>
+#include <xfs/libxfs.h>
 #include "block.h"
 #include "bmap.h"
 #include "command.h"
-#include "data.h"
 #include "type.h"
 #include "faddr.h"
 #include "fprint.h"
@@ -42,7 +41,7 @@
 #include "inode.h"
 #include "io.h"
 #include "output.h"
-#include "mount.h"
+#include "init.h"
 
 static int	ablock_f(int argc, char **argv);
 static void     ablock_help(void);
@@ -58,7 +57,7 @@ static const cmdinfo_t	ablock_cmd =
 	{ "ablock", NULL, ablock_f, 1, 1, 1, "filoff",
 	  "set address to file offset (attr fork)", ablock_help };
 static const cmdinfo_t	daddr_cmd =
-	{ "daddr", NULL, daddr_f, 0, 1, 1, "[d]", 
+	{ "daddr", NULL, daddr_f, 0, 1, 1, "[d]",
 	  "set address to daddr value", daddr_help };
 static const cmdinfo_t	dblock_cmd =
 	{ "dblock", NULL, dblock_f, 1, 1, 1, "filoff",
@@ -67,7 +66,7 @@ static const cmdinfo_t	fsblock_cmd =
 	{ "fsblock", "fsb", fsblock_f, 0, 1, 1, "[fsb]",
 	  "set address to fsblock value", fsblock_help };
 
-static void 
+static void
 ablock_help(void)
 {
 	dbprintf(
@@ -127,7 +126,7 @@ block_init(void)
 	add_command(&fsblock_cmd);
 }
 
-static void 
+static void
 daddr_help(void)
 {
 	dbprintf(
@@ -161,7 +160,7 @@ daddr_f(
 	return 0;
 }
 
-static void 
+static void
 dblock_help(void)
 {
 	dbprintf(
@@ -218,7 +217,7 @@ dblock_f(
 	return 0;
 }
 
-static void 
+static void
 fsblock_help(void)
 {
 	dbprintf(
