@@ -1,37 +1,36 @@
 /*
  * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#include <libxfs.h>
-#include <getopt.h>
+#include <xfs/libxfs.h>
 #include "addr.h"
 #include "agf.h"
 #include "agfl.h"
@@ -58,7 +57,6 @@
 #include "print.h"
 #include "quit.h"
 #include "sb.h"
-#include "uuid.h"
 #include "write.h"
 #include "malloc.h"
 #include "dquot.h"
@@ -66,8 +64,6 @@
 cmdinfo_t	*cmdtab;
 int		ncmds;
 
-static int	cmd_compare(const void *a, const void *b);
-
 static int
 cmd_compare(const void *a, const void *b)
 {
@@ -151,7 +147,6 @@ init_commands(void)
 	print_init();
 	quit_init();
 	sb_init();
-	uuid_init();
 	type_init();
 	write_init();
 	dquot_init();
