@@ -1,41 +1,40 @@
 /*
  * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#include <libxfs.h>
+#include <xfs/libxfs.h>
 #include "command.h"
-#include "data.h"
 #include "convert.h"
 #include "output.h"
-#include "mount.h"
+#include "init.h"
 
 #define	M(A)	(1 << CT_ ## A)
 #define	agblock_to_bytes(x)	\
@@ -56,7 +55,7 @@
 	((__uint64_t)(x) << mp->m_sb.sb_inodelog)
 
 typedef enum {
-	CT_NONE = -1, 
+	CT_NONE = -1,
 	CT_AGBLOCK,		/* xfs_agblock_t */
 	CT_AGINO,		/* xfs_agino_t */
 	CT_AGNUMBER,		/* xfs_agno_t */
@@ -161,6 +160,7 @@ bytevalue(ctype_t ctype, cval_t *val)
 		return (__uint64_t)val->inooff;
 	case CT_NONE:
 	case NCTS:
+		break;
 	}
 	/* NOTREACHED */
 	return 0;
@@ -261,6 +261,7 @@ convert_f(int argc, char **argv)
 	case CT_NONE:
 	case NCTS:
 		/* NOTREACHED */
+		break;
 	}
 	dbprintf("0x%llx (%llu)\n", v, v);
 	return 0;
@@ -320,6 +321,7 @@ getvalue(char *s, ctype_t ctype, cval_t *val)
 	case CT_NONE:
 	case NCTS:
 		/* NOTREACHED */
+		break;
 	}
 	return 1;
 }
