@@ -1,37 +1,36 @@
 /*
- * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ * Copyright (c) 2000-2001,2004 Silicon Graphics, Inc.  All Rights Reserved.
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#include <libxfs.h>
-#include "data.h"
+#include <xfs/libxfs.h>
 #include "type.h"
 #include "faddr.h"
 #include "inode.h"
@@ -39,7 +38,7 @@
 #include "bit.h"
 #include "bmap.h"
 #include "output.h"
-#include "mount.h"
+#include "init.h"
 
 void
 fa_agblock(
@@ -185,6 +184,7 @@ fa_cfsblock(
 	typnm_t		next)
 {
 	xfs_dfsbno_t	bno;
+	int		nb;
 
 	bno = (xfs_dfsbno_t)getbitval(obj, bit, BMBT_STARTBLOCK_BITLEN,
 		BVUNSIGNED);
@@ -192,9 +192,10 @@ fa_cfsblock(
 		dbprintf("null block number, cannot set new addr\n");
 		return;
 	}
+	nb = next == TYP_DIR2 ? mp->m_dirblkfsbs : 1;
 	ASSERT(typtab[next].typnm == next);
-	set_cur(&typtab[next], XFS_FSB_TO_DADDR(mp, bno), blkbb, DB_RING_ADD,
-		NULL);
+	set_cur(&typtab[next], XFS_FSB_TO_DADDR(mp, bno), nb * blkbb,
+		DB_RING_ADD, NULL);
 }
 
 void
@@ -309,7 +310,7 @@ fa_dirblock(
 	if (nex > 1)
 		make_bbmap(&bbmap, nex, bmp);
 	set_cur(&typtab[next], (__int64_t)XFS_FSB_TO_DADDR(mp, dfsbno),
-		(int)XFS_FSB_TO_DADDR(mp, mp->m_dirblkfsbs), DB_RING_ADD, 
+		XFS_FSB_TO_BB(mp, mp->m_dirblkfsbs), DB_RING_ADD,
 		nex > 1 ? &bbmap : NULL);
 	free(bmp);
 }
