@@ -1,37 +1,36 @@
 /*
  * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#include <libxfs.h>
-#include <getopt.h>
+#include <xfs/libxfs.h>
 #include <ctype.h>
 #include <time.h>
 #include "type.h"
@@ -68,7 +67,7 @@ fp_charns(
 	     i++, p++) {
 		if (*p == '\\' || *p == '\'' || *p == '"' || *p == '\?')
 			dbprintf("\\%c", *p);
-		else if (isgraph(*p) || *p == ' ')
+		else if (isgraph((int)*p) || *p == ' ')
 			dbprintf("%c", *p);
 		else if (*p == '\a' || *p == '\b' || *p == '\f' || *p == '\n' ||
 			 *p == '\r' || *p == '\t' || *p == '\v')
@@ -153,7 +152,7 @@ fp_time(
 	int	bitpos;
 	char	*c;
 	int	i;
-        time_t  t;
+	time_t  t;
 
 	ASSERT(bitoffs(bit) == 0);
 	for (i = 0, bitpos = bit;
@@ -161,7 +160,7 @@ fp_time(
 	     i++, bitpos += size) {
 		if (array)
 			dbprintf("%d:", i + base);
-                t=(time_t)getbitval((char *)obj + byteize(bitpos), 0, sizeof(int32_t)*8, 0);
+		t=(time_t)getbitval((char *)obj + byteize(bitpos), 0, sizeof(int32_t)*8, 0);
 		c = ctime(&t);
 		dbprintf("%24.24s", c);
 		if (i < count - 1)
