@@ -122,6 +122,21 @@ const field_t	inode_core_flds[] = {
 	{ "realtime", FLDT_UINT1,
 	  OI(COFF(flags) + bitsz(__uint16_t) - XFS_DIFLAG_REALTIME_BIT - 1), C1,
 	  0, TYP_NONE },
+	{ "immutable", FLDT_UINT1,
+	  OI(COFF(flags) + bitsz(__uint16_t) - XFS_DIFLAG_IMMUTABLE_BIT-1), C1,
+	  0, TYP_NONE },
+	{ "append", FLDT_UINT1,
+	  OI(COFF(flags) + bitsz(__uint16_t) - XFS_DIFLAG_APPEND_BIT - 1), C1,
+	  0, TYP_NONE },
+	{ "sync", FLDT_UINT1,
+	  OI(COFF(flags) + bitsz(__uint16_t) - XFS_DIFLAG_SYNC_BIT - 1), C1,
+	  0, TYP_NONE },
+	{ "noatime", FLDT_UINT1,
+	  OI(COFF(flags) + bitsz(__uint16_t) - XFS_DIFLAG_NOATIME_BIT - 1), C1,
+	  0, TYP_NONE },
+	{ "nodump", FLDT_UINT1,
+	  OI(COFF(flags) + bitsz(__uint16_t) - XFS_DIFLAG_NODUMP_BIT - 1), C1,
+	  0, TYP_NONE },
 	{ "gen", FLDT_UINT32D, OI(COFF(gen)), C1, 0, TYP_NONE },
 	{ NULL }
 };
@@ -375,12 +390,12 @@ inode_init(void)
 typnm_t
 inode_next_type(void)
 {
-	switch (iocur_top->mode & IFMT) {
-	case IFDIR:
+	switch (iocur_top->mode & S_IFMT) {
+	case S_IFDIR:
 		return XFS_DIR_IS_V2(mp) ? TYP_DIR2 : TYP_DIR;
-	case IFLNK:
+	case S_IFLNK:
 		return TYP_SYMLINK;
-	case IFREG:
+	case S_IFREG:
 		if (iocur_top->ino == mp->m_sb.sb_rbmino)
 			return TYP_RTBITMAP;
 		else if (iocur_top->ino == mp->m_sb.sb_rsumino)
@@ -445,7 +460,7 @@ inode_u_c_count(
 	dip = obj;
 	ASSERT((char *)&dip->di_u - (char *)dip == byteize(startoff));
 	return INT_GET(dip->di_core.di_format, ARCH_CONVERT) == XFS_DINODE_FMT_LOCAL &&
-	       (INT_GET(dip->di_core.di_mode, ARCH_CONVERT) & IFMT) == IFREG ?
+	       (INT_GET(dip->di_core.di_mode, ARCH_CONVERT) & S_IFMT) == S_IFREG ?
 		(int)INT_GET(dip->di_core.di_size, ARCH_CONVERT) : 0;
 }
 
@@ -489,7 +504,7 @@ inode_u_sfdir_count(
 	dip = obj;
 	ASSERT((char *)&dip->di_u - (char *)dip == byteize(startoff));
 	return INT_GET(dip->di_core.di_format, ARCH_CONVERT) == XFS_DINODE_FMT_LOCAL &&
-	       (INT_GET(dip->di_core.di_mode, ARCH_CONVERT) & IFMT) == IFDIR
+	       (INT_GET(dip->di_core.di_mode, ARCH_CONVERT) & S_IFMT) == S_IFDIR
 	       && XFS_DIR_IS_V1(mp);
 }
 
@@ -505,7 +520,7 @@ inode_u_sfdir2_count(
 	dip = obj;
 	ASSERT((char *)&dip->di_u - (char *)dip == byteize(startoff));
 	return INT_GET(dip->di_core.di_format, ARCH_CONVERT) == XFS_DINODE_FMT_LOCAL &&
-	       (INT_GET(dip->di_core.di_mode, ARCH_CONVERT) & IFMT) == IFDIR &&
+	       (INT_GET(dip->di_core.di_mode, ARCH_CONVERT) & S_IFMT) == S_IFDIR &&
 	       XFS_DIR_IS_V2(mp);
 }
 
@@ -548,7 +563,7 @@ inode_u_symlink_count(
 	dip = obj;
 	ASSERT((char *)&dip->di_u - (char *)dip == byteize(startoff));
 	return INT_GET(dip->di_core.di_format, ARCH_CONVERT) == XFS_DINODE_FMT_LOCAL &&
-	       (INT_GET(dip->di_core.di_mode, ARCH_CONVERT) & IFMT) == IFLNK ?
+	       (INT_GET(dip->di_core.di_mode, ARCH_CONVERT) & S_IFMT) == S_IFLNK ?
 		(int)INT_GET(dip->di_core.di_size, ARCH_CONVERT) : 0;
 }
 
@@ -586,7 +601,7 @@ set_cur_inode(
 	dip = iocur_top->data;
 	iocur_top->ino = ino;
 	iocur_top->mode = INT_GET(dip->di_core.di_mode, ARCH_CONVERT);
-	if ((iocur_top->mode & IFMT) == IFDIR)
+	if ((iocur_top->mode & S_IFMT) == S_IFDIR)
 		iocur_top->dirino = ino;
 
 	/* track updated info in ring */
