@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2003 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2004 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -32,6 +32,9 @@
 #ifndef __LIBXFS_H__
 #define __LIBXFS_H__
 
+#define XFS_BIG_INUMS	1
+#define XFS_BIG_BLKNOS	1
+
 #include <xfs/platform_defs.h>
 
 #include <xfs/xfs_fs.h>
@@ -114,7 +117,8 @@ typedef struct {
 #define LIBXFS_EXIT_ON_FAILURE	0x0001	/* exit the program if a call fails */
 #define LIBXFS_ISREADONLY	0x0002	/* disallow all mounted filesystems */
 #define LIBXFS_ISINACTIVE	0x0004	/* allow mounted only if mounted ro */
-#define LIBXFS_DANGEROUSLY	0x0008	/* repair is mounted ro */
+#define LIBXFS_DANGEROUSLY	0x0008	/* repairing a device mounted ro    */
+#define LIBXFS_EXCLUSIVELY	0x0010	/* disallow other accesses (O_EXCL) */
 
 extern char	*progname;
 extern int	libxfs_init (libxfs_init_t *);
@@ -357,10 +361,11 @@ typedef struct {
 } cred_t;
 
 extern int	libxfs_inode_alloc (xfs_trans_t **, xfs_inode_t *, mode_t,
-				ushort, dev_t, cred_t *, xfs_inode_t **);
+				ushort, xfs_dev_t, cred_t *, xfs_inode_t **);
 extern void	libxfs_trans_inode_alloc_buf (xfs_trans_t *, xfs_buf_t *);
 
 extern void	libxfs_idata_realloc (xfs_inode_t *, int, int);
+extern void	libxfs_idestroy_fork (xfs_inode_t *, int);
 extern int	libxfs_iread (xfs_mount_t *, xfs_trans_t *, xfs_ino_t,
 				xfs_inode_t **, xfs_daddr_t);
 extern void	libxfs_ichgtime (xfs_inode_t *, int);
