@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2003-2004 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -30,16 +30,7 @@
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-extern int	exitcode;
 extern char	*progname;
-
-extern int	fdesc;
-extern char	*fname;
-extern struct xfs_fsop_geom	fgeom;
-
-extern int	readonly;
-extern int	directio;
-extern int	realtime;
-extern int	append;
-extern int	osync;
-extern int	trunc;
+extern int	exitcode;
+extern int	expert;
+extern size_t	pagesize;
