@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2003 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2004 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -70,19 +70,11 @@ lvm_get_subvol_stripe(
 		largv[0] = "/sbin/lvdisplay";
 	else {
 		fprintf(stderr,
-			"Warning - LVM device, but no lvdisplay(8) found\n");
+			_("Warning - LVM device, but no lvdisplay(8) found\n"));
 		return 0;
 	}
 
-	/* lvm tools want the full, real path to a logical volume.
-	 * (lvm doesn't really open the file, it just wants a
-	 * string that happens to look like a path :/ )
-	 */
-	if (dfile[0] != '/') {
-		getcwd(tmppath, MAXPATHLEN);
-		strcat(tmppath, "/");
-		dfile = strcat(tmppath, dfile);
-	}
+	/* realpath gives an absolute pathname */
 	largv[1] = realpath(dfile, tmppath);
 	largv[2] = NULL;
 
