@@ -536,8 +536,8 @@ xfs_alloc_ag_vextent(
 			xfs_trans_mod_sb(args->tp,
 				args->wasdel ? XFS_TRANS_SB_RES_FDBLOCKS :
 					XFS_TRANS_SB_FDBLOCKS, -slen);
-		XFS_STATS_INC(xfsstats.xs_allocx);
-		XFS_STATS_ADD(xfsstats.xs_allocb, args->len);
+		XFS_STATS_INC(xs_allocx);
+		XFS_STATS_ADD(xs_allocb, args->len);
 	}
 	return 0;
 }
@@ -687,14 +687,8 @@ xfs_alloc_ag_vextent_near(
 	/*
 	 * Randomly don't execute the first algorithm.
 	 */
-	static int	seed;		/* randomizing seed value */
 	int		dofirst;	/* set to do first algorithm */
-	timespec_t	now;		/* current time */
 
-	if (!seed) {
-		nanotime(&now);
-		seed = (int)now.tv_sec ^ (int)now.tv_nsec;
-	}
 	dofirst = random() & 1;
 #endif
 	/*
@@ -1681,8 +1675,8 @@ xfs_free_ag_extent(
 		xfs_alloc_log_agf(tp, agbp, XFS_AGF_FREEBLKS);
 		if (!isfl)
 			xfs_trans_mod_sb(tp, XFS_TRANS_SB_FDBLOCKS, (long)len);
-		XFS_STATS_INC(xfsstats.xs_freex);
-		XFS_STATS_ADD(xfsstats.xs_freeb, len);
+		XFS_STATS_INC(xs_freex);
+		XFS_STATS_ADD(xs_freeb, len);
 	}
 	TRACE_FREE(haveleft ?
 			(haveright ? "both" : "left") :
