@@ -97,7 +97,7 @@ xfs_alloc_delrec(
 		*stat = 0;
 		return 0;
 	}
-	XFS_STATS_INC(xfsstats.xs_abt_delrec);
+	XFS_STATS_INC(xs_abt_delrec);
 	/*
 	 * It's a nonleaf.  Excise the key and ptr being deleted, by
 	 * sliding the entries past them down one.
@@ -595,7 +595,7 @@ xfs_alloc_insrec(
 	 * and we're done.
 	 */
 	if (level >= cur->bc_nlevels) {
-		XFS_STATS_INC(xfsstats.xs_abt_insrec);
+		XFS_STATS_INC(xs_abt_insrec);
 		if ((error = xfs_alloc_newroot(cur, &i)))
 			return error;
 		*bnop = NULLAGBLOCK;
@@ -615,7 +615,7 @@ xfs_alloc_insrec(
 		*stat = 0;
 		return 0;
 	}
-	XFS_STATS_INC(xfsstats.xs_abt_insrec);
+	XFS_STATS_INC(xs_abt_insrec);
 	/*
 	 * Get pointers to the btree buffer and block.
 	 */
@@ -915,7 +915,7 @@ xfs_alloc_lookup(
 	int			level;	/* level in the btree */
 	xfs_mount_t		*mp;	/* file system mount point */
 
-	XFS_STATS_INC(xfsstats.xs_abt_lookup);
+	XFS_STATS_INC(xs_abt_lookup);
 	/*
 	 * Get the allocation group header, and the root block number.
 	 */
@@ -1010,7 +1010,7 @@ xfs_alloc_lookup(
 				xfs_extlen_t	blockcount;	/* key value */
 				xfs_agblock_t	startblock;	/* key value */
 
-				XFS_STATS_INC(xfsstats.xs_abt_compare);
+				XFS_STATS_INC(xs_abt_compare);
 				/*
 				 * keyno is average of low and high.
 				 */
