@@ -98,7 +98,7 @@ xfs_bmbt_delrec(
 		*stat = 0;
 		return 0;
 	}
-	XFS_STATS_INC(xfsstats.xs_bmbt_delrec);
+	XFS_STATS_INC(xs_bmbt_delrec);
 	if (level > 0) {
 		kp = XFS_BMAP_KEY_IADDR(block, 1, cur);
 		pp = XFS_BMAP_PTR_IADDR(block, 1, cur);
@@ -449,7 +449,7 @@ xfs_bmbt_insrec(
 		*stat = 0;
 		return 0;
 	}
-	XFS_STATS_INC(xfsstats.xs_bmbt_insrec);
+	XFS_STATS_INC(xs_bmbt_insrec);
 	block = xfs_bmbt_get_block(cur, level, &bp);
 	numrecs = INT_GET(block->bb_numrecs, ARCH_CONVERT);
 #ifdef DEBUG
@@ -802,7 +802,7 @@ xfs_bmbt_lookup(
 	xfs_fileoff_t		startoff;
 	xfs_trans_t		*tp;
 
-	XFS_STATS_INC(xfsstats.xs_bmbt_lookup);
+	XFS_STATS_INC(xs_bmbt_lookup);
 	XFS_BMBT_TRACE_CURSOR(cur, ENTRY);
 	XFS_BMBT_TRACE_ARGI(cur, (int)dir);
 	tp = cur->bc_tp;
@@ -847,7 +847,7 @@ xfs_bmbt_lookup(
 				return 0;
 			}
 			while (low <= high) {
-				XFS_STATS_INC(xfsstats.xs_bmbt_compare);
+				XFS_STATS_INC(xs_bmbt_compare);
 				keyno = (low + high) >> 1;
 				if (level > 0) {
 					kkp = kkbase + keyno - 1;
@@ -1564,7 +1564,7 @@ __xfs_bmbt_get_all(
 	ext_flag = (int)(l0 >> (64 - BMBT_EXNTFLAG_BITLEN));
 	s->br_startoff = ((xfs_fileoff_t)l0 &
 			   XFS_MASK64LO(64 - BMBT_EXNTFLAG_BITLEN)) >> 9;
-#if XFS_BIG_FILESYSTEMS
+#if XFS_BIG_BLKNOS
 	s->br_startblock = (((xfs_fsblock_t)l0 & XFS_MASK64LO(9)) << 43) |
 			   (((xfs_fsblock_t)l1) >> 21);
 #else
@@ -1580,7 +1580,7 @@ __xfs_bmbt_get_all(
 #else	/* !DEBUG */
 	s->br_startblock = (xfs_fsblock_t)(((xfs_dfsbno_t)l1) >> 21);
 #endif	/* DEBUG */
-#endif	/* XFS_BIG_FILESYSTEMS */
+#endif	/* XFS_BIG_BLKNOS */
 	s->br_blockcount = (xfs_filblks_t)(l1 & XFS_MASK64LO(21));
 	/* This is xfs_extent_state() in-line */
 	if (ext_flag) {
@@ -1641,7 +1641,7 @@ xfs_fsblock_t
 xfs_bmbt_get_startblock(
 	xfs_bmbt_rec_t	*r)
 {
-#if XFS_BIG_FILESYSTEMS
+#if XFS_BIG_BLKNOS
 	return (((xfs_fsblock_t)r->l0 & XFS_MASK64LO(9)) << 43) |
 	       (((xfs_fsblock_t)r->l1) >> 21);
 #else
@@ -1655,7 +1655,7 @@ xfs_bmbt_get_startblock(
 #else	/* !DEBUG */
 	return (xfs_fsblock_t)(((xfs_dfsbno_t)r->l1) >> 21);
 #endif	/* DEBUG */
-#endif	/* XFS_BIG_FILESYSTEMS */
+#endif	/* XFS_BIG_BLKNOS */
 }
 
 /*
@@ -1712,7 +1712,7 @@ xfs_fsblock_t
 xfs_bmbt_disk_get_startblock(
 	xfs_bmbt_rec_t	*r)
 {
-#if XFS_BIG_FILESYSTEMS
+#if XFS_BIG_BLKNOS
 	return (((xfs_fsblock_t)INT_GET(r->l0, ARCH_CONVERT) & XFS_MASK64LO(9)) << 43) |
 	       (((xfs_fsblock_t)INT_GET(r->l1, ARCH_CONVERT)) >> 21);
 #else
@@ -1726,7 +1726,7 @@ xfs_bmbt_disk_get_startblock(
 #else	/* !DEBUG */
 	return (xfs_fsblock_t)(((xfs_dfsbno_t)INT_GET(r->l1, ARCH_CONVERT)) >> 21);
 #endif	/* DEBUG */
-#endif	/* XFS_BIG_FILESYSTEMS */
+#endif	/* XFS_BIG_BLKNOS */
 }
 
 /*
@@ -2137,17 +2137,15 @@ xfs_bmbt_set_all(
 	extent_flag = (s->br_state == XFS_EXT_NORM) ? 0 : 1;
 	ASSERT((s->br_startoff & XFS_MASK64HI(9)) == 0);
 	ASSERT((s->br_blockcount & XFS_MASK64HI(43)) == 0);
-#if XFS_BIG_FILESYSTEMS
+#if XFS_BIG_BLKNOS
 	ASSERT((s->br_startblock & XFS_MASK64HI(12)) == 0);
-#endif	/* XFS_BIG_FILESYSTEMS */
-#if XFS_BIG_FILESYSTEMS
 	r->l0 = ((xfs_bmbt_rec_base_t)extent_flag << 63) |
 		 ((xfs_bmbt_rec_base_t)s->br_startoff << 9) |
 		 ((xfs_bmbt_rec_base_t)s->br_startblock >> 43);
 	r->l1 = ((xfs_bmbt_rec_base_t)s->br_startblock << 21) |
 		 ((xfs_bmbt_rec_base_t)s->br_blockcount &
 		 (xfs_bmbt_rec_base_t)XFS_MASK64LO(21));
-#else	/* !XFS_BIG_FILESYSTEMS */
+#else	/* !XFS_BIG_BLKNOS */
 	if (ISNULLSTARTBLOCK(s->br_startblock)) {
 		r->l0 = ((xfs_bmbt_rec_base_t)extent_flag << 63) |
 			((xfs_bmbt_rec_base_t)s->br_startoff << 9) |
@@ -2163,7 +2161,7 @@ xfs_bmbt_set_all(
 			  ((xfs_bmbt_rec_base_t)s->br_blockcount &
 			   (xfs_bmbt_rec_base_t)XFS_MASK64LO(21));
 	}
-#endif	/* XFS_BIG_FILESYSTEMS */
+#endif	/* XFS_BIG_BLKNOS */
 }
 
 /*
@@ -2183,17 +2181,15 @@ xfs_bmbt_set_allf(
 	extent_flag = (v == XFS_EXT_NORM) ? 0 : 1;
 	ASSERT((o & XFS_MASK64HI(64-BMBT_STARTOFF_BITLEN)) == 0);
 	ASSERT((c & XFS_MASK64HI(64-BMBT_BLOCKCOUNT_BITLEN)) == 0);
-#if XFS_BIG_FILESYSTEMS
+#if XFS_BIG_BLKNOS
 	ASSERT((b & XFS_MASK64HI(64-BMBT_STARTBLOCK_BITLEN)) == 0);
-#endif	/* XFS_BIG_FILESYSTEMS */
-#if XFS_BIG_FILESYSTEMS
 	r->l0 = ((xfs_bmbt_rec_base_t)extent_flag << 63) |
 		((xfs_bmbt_rec_base_t)o << 9) |
 		((xfs_bmbt_rec_base_t)b >> 43);
 	r->l1 = ((xfs_bmbt_rec_base_t)b << 21) |
 		((xfs_bmbt_rec_base_t)c &
 		(xfs_bmbt_rec_base_t)XFS_MASK64LO(21));
-#else	/* !XFS_BIG_FILESYSTEMS */
+#else	/* !XFS_BIG_BLKNOS */
 	if (ISNULLSTARTBLOCK(b)) {
 		r->l0 = ((xfs_bmbt_rec_base_t)extent_flag << 63) |
 			((xfs_bmbt_rec_base_t)o << 9) |
@@ -2209,7 +2205,7 @@ xfs_bmbt_set_allf(
 			 ((xfs_bmbt_rec_base_t)c &
 			 (xfs_bmbt_rec_base_t)XFS_MASK64LO(21));
 	}
-#endif	/* XFS_BIG_FILESYSTEMS */
+#endif	/* XFS_BIG_BLKNOS */
 }
 
 #if ARCH_CONVERT != ARCH_NOCONVERT
@@ -2228,17 +2224,15 @@ xfs_bmbt_disk_set_all(
 	extent_flag = (s->br_state == XFS_EXT_NORM) ? 0 : 1;
 	ASSERT((s->br_startoff & XFS_MASK64HI(9)) == 0);
 	ASSERT((s->br_blockcount & XFS_MASK64HI(43)) == 0);
-#if XFS_BIG_FILESYSTEMS
+#if XFS_BIG_BLKNOS
 	ASSERT((s->br_startblock & XFS_MASK64HI(12)) == 0);
-#endif	/* XFS_BIG_FILESYSTEMS */
-#if XFS_BIG_FILESYSTEMS
 	INT_SET(r->l0, ARCH_CONVERT, ((xfs_bmbt_rec_base_t)extent_flag << 63) |
 		  ((xfs_bmbt_rec_base_t)s->br_startoff << 9) |
 		  ((xfs_bmbt_rec_base_t)s->br_startblock >> 43));
 	INT_SET(r->l1, ARCH_CONVERT, ((xfs_bmbt_rec_base_t)s->br_startblock << 21) |
 		  ((xfs_bmbt_rec_base_t)s->br_blockcount &
 		   (xfs_bmbt_rec_base_t)XFS_MASK64LO(21)));
-#else	/* !XFS_BIG_FILESYSTEMS */
+#else	/* !XFS_BIG_BLKNOS */
 	if (ISNULLSTARTBLOCK(s->br_startblock)) {
 		INT_SET(r->l0, ARCH_CONVERT, ((xfs_bmbt_rec_base_t)extent_flag << 63) |
 			((xfs_bmbt_rec_base_t)s->br_startoff << 9) |
@@ -2254,7 +2248,7 @@ xfs_bmbt_disk_set_all(
 			  ((xfs_bmbt_rec_base_t)s->br_blockcount &
 			   (xfs_bmbt_rec_base_t)XFS_MASK64LO(21)));
 	}
-#endif	/* XFS_BIG_FILESYSTEMS */
+#endif	/* XFS_BIG_BLKNOS */
 }
 
 /*
@@ -2274,17 +2268,15 @@ xfs_bmbt_disk_set_allf(
 	extent_flag = (v == XFS_EXT_NORM) ? 0 : 1;
 	ASSERT((o & XFS_MASK64HI(64-BMBT_STARTOFF_BITLEN)) == 0);
 	ASSERT((c & XFS_MASK64HI(64-BMBT_BLOCKCOUNT_BITLEN)) == 0);
-#if XFS_BIG_FILESYSTEMS
+#if XFS_BIG_BLKNOS
 	ASSERT((b & XFS_MASK64HI(64-BMBT_STARTBLOCK_BITLEN)) == 0);
-#endif	/* XFS_BIG_FILESYSTEMS */
-#if XFS_BIG_FILESYSTEMS
 	INT_SET(r->l0, ARCH_CONVERT, ((xfs_bmbt_rec_base_t)extent_flag << 63) |
 		((xfs_bmbt_rec_base_t)o << 9) |
 		((xfs_bmbt_rec_base_t)b >> 43));
 	INT_SET(r->l1, ARCH_CONVERT, ((xfs_bmbt_rec_base_t)b << 21) |
 		  ((xfs_bmbt_rec_base_t)c &
 		   (xfs_bmbt_rec_base_t)XFS_MASK64LO(21)));
-#else	/* !XFS_BIG_FILESYSTEMS */
+#else	/* !XFS_BIG_BLKNOS */
 	if (ISNULLSTARTBLOCK(b)) {
 		INT_SET(r->l0, ARCH_CONVERT, ((xfs_bmbt_rec_base_t)extent_flag << 63) |
 			((xfs_bmbt_rec_base_t)o << 9) |
@@ -2300,7 +2292,7 @@ xfs_bmbt_disk_set_allf(
 			  ((xfs_bmbt_rec_base_t)c &
 			   (xfs_bmbt_rec_base_t)XFS_MASK64LO(21)));
 	}
-#endif	/* XFS_BIG_FILESYSTEMS */
+#endif	/* XFS_BIG_BLKNOS */
 }
 #endif
 
@@ -2325,15 +2317,13 @@ xfs_bmbt_set_startblock(
 	xfs_bmbt_rec_t	*r,
 	xfs_fsblock_t	v)
 {
-#if XFS_BIG_FILESYSTEMS
+#if XFS_BIG_BLKNOS
 	ASSERT((v & XFS_MASK64HI(12)) == 0);
-#endif	/* XFS_BIG_FILESYSTEMS */
-#if XFS_BIG_FILESYSTEMS
 	r->l0 = (r->l0 & (xfs_bmbt_rec_base_t)XFS_MASK64HI(55)) |
 		  (xfs_bmbt_rec_base_t)(v >> 43);
 	r->l1 = (r->l1 & (xfs_bmbt_rec_base_t)XFS_MASK64LO(21)) |
 		  (xfs_bmbt_rec_base_t)(v << 21);
-#else	/* !XFS_BIG_FILESYSTEMS */
+#else	/* !XFS_BIG_BLKNOS */
 	if (ISNULLSTARTBLOCK(v)) {
 		r->l0 |= (xfs_bmbt_rec_base_t)XFS_MASK64LO(9);
 		r->l1 = (xfs_bmbt_rec_base_t)XFS_MASK64HI(11) |
@@ -2344,7 +2334,7 @@ xfs_bmbt_set_startblock(
 		r->l1 = ((xfs_bmbt_rec_base_t)v << 21) |
 			  (r->l1 & (xfs_bmbt_rec_base_t)XFS_MASK64LO(21));
 	}
-#endif	/* XFS_BIG_FILESYSTEMS */
+#endif	/* XFS_BIG_BLKNOS */
 }
 
 /*
