@@ -11,7 +11,7 @@
  *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
- * or the like.	 Any license provided herein, whether implied or
+ * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
@@ -71,7 +71,7 @@ xfs_btree_maxrecs(
 STATIC int				/* number of records fitting in block */
 xfs_btree_maxrecs(
 	xfs_btree_cur_t		*cur,	/* btree cursor */
-	xfs_btree_block_t	*block) /* generic btree block pointer */
+	xfs_btree_block_t	*block)	/* generic btree block pointer */
 {
 	switch (cur->bc_btnum) {
 	case XFS_BTNUM_BNO:
@@ -98,7 +98,7 @@ xfs_btree_maxrecs(
 void
 xfs_btree_check_block(
 	xfs_btree_cur_t		*cur,	/* btree cursor */
-	xfs_btree_block_t	*block, /* generic btree block pointer */
+	xfs_btree_block_t	*block,	/* generic btree block pointer */
 	int			level,	/* level of the btree block */
 	xfs_buf_t		*bp)	/* buffer containing block, if any */
 {
@@ -121,8 +121,8 @@ xfs_btree_check_key(
 {
 	switch (btnum) {
 	case XFS_BTNUM_BNO: {
-		xfs_alloc_key_t *k1;
-		xfs_alloc_key_t *k2;
+		xfs_alloc_key_t	*k1;
+		xfs_alloc_key_t	*k2;
 
 		k1 = ak1;
 		k2 = ak2;
@@ -130,8 +130,8 @@ xfs_btree_check_key(
 		break;
 	    }
 	case XFS_BTNUM_CNT: {
-		xfs_alloc_key_t *k1;
-		xfs_alloc_key_t *k2;
+		xfs_alloc_key_t	*k1;
+		xfs_alloc_key_t	*k2;
 
 		k1 = ak1;
 		k2 = ak2;
@@ -150,8 +150,8 @@ xfs_btree_check_key(
 		break;
 	    }
 	case XFS_BTNUM_INO: {
-		xfs_inobt_key_t *k1;
-		xfs_inobt_key_t *k2;
+		xfs_inobt_key_t	*k1;
+		xfs_inobt_key_t	*k2;
 
 		k1 = ak1;
 		k2 = ak2;
@@ -171,7 +171,7 @@ xfs_btree_check_key(
 int					/* error (0 or EFSCORRUPTED) */
 xfs_btree_check_lblock(
 	xfs_btree_cur_t		*cur,	/* btree cursor */
-	xfs_btree_lblock_t	*block, /* btree long form block pointer */
+	xfs_btree_lblock_t	*block,	/* btree long form block pointer */
 	int			level,	/* level of the btree block */
 	xfs_buf_t		*bp)	/* buffer for block, if any */
 {
@@ -190,15 +190,12 @@ xfs_btree_check_lblock(
 		!INT_ISZERO(block->bb_rightsib, ARCH_CONVERT) &&
 		(INT_GET(block->bb_rightsib, ARCH_CONVERT) == NULLDFSBNO ||
 		 XFS_FSB_SANITY_CHECK(mp, INT_GET(block->bb_rightsib, ARCH_CONVERT)));
-	if (XFS_TEST_ERROR(!lblock_ok, mp, XFS_ERRTAG_BTREE_CHECK_LBLOCK,
-			XFS_RANDOM_BTREE_CHECK_LBLOCK)) {
+	if (unlikely(XFS_TEST_ERROR(!lblock_ok, mp, XFS_ERRTAG_BTREE_CHECK_LBLOCK,
+			XFS_RANDOM_BTREE_CHECK_LBLOCK))) {
 		if (bp)
 			xfs_buftrace("LBTREE ERROR", bp);
-#ifdef __KERNEL__	/* additional, temporary, debugging code */
-		cmn_err(CE_NOTE,
-			"EFSCORRUPTED returned from file %s line %d",
-			__FILE__, __LINE__);
-#endif
+		XFS_ERROR_REPORT("xfs_btree_check_lblock", XFS_ERRLEVEL_LOW,
+				 mp);
 		return XFS_ERROR(EFSCORRUPTED);
 	}
 	return 0;
@@ -209,7 +206,7 @@ xfs_btree_check_lblock(
  */
 int					/* error (0 or EFSCORRUPTED) */
 xfs_btree_check_lptr(
-	xfs_btree_cur_t *cur,		/* btree cursor */
+	xfs_btree_cur_t	*cur,		/* btree cursor */
 	xfs_dfsbno_t	ptr,		/* btree block disk address */
 	int		level)		/* btree block level */
 {
@@ -235,8 +232,8 @@ xfs_btree_check_rec(
 {
 	switch (btnum) {
 	case XFS_BTNUM_BNO: {
-		xfs_alloc_rec_t *r1;
-		xfs_alloc_rec_t *r2;
+		xfs_alloc_rec_t	*r1;
+		xfs_alloc_rec_t	*r2;
 
 		r1 = ar1;
 		r2 = ar2;
@@ -245,8 +242,8 @@ xfs_btree_check_rec(
 		break;
 	    }
 	case XFS_BTNUM_CNT: {
-		xfs_alloc_rec_t *r1;
-		xfs_alloc_rec_t *r2;
+		xfs_alloc_rec_t	*r1;
+		xfs_alloc_rec_t	*r2;
 
 		r1 = ar1;
 		r2 = ar2;
@@ -261,14 +258,14 @@ xfs_btree_check_rec(
 
 		r1 = ar1;
 		r2 = ar2;
-		ASSERT(xfs_bmbt_get_startoff(r1) +
-		       xfs_bmbt_get_blockcount(r1) <=
-		       xfs_bmbt_get_startoff(r2));
+		ASSERT(xfs_bmbt_disk_get_startoff(r1) +
+		       xfs_bmbt_disk_get_blockcount(r1) <=
+		       xfs_bmbt_disk_get_startoff(r2));
 		break;
 	    }
 	case XFS_BTNUM_INO: {
-		xfs_inobt_rec_t *r1;
-		xfs_inobt_rec_t *r2;
+		xfs_inobt_rec_t	*r1;
+		xfs_inobt_rec_t	*r2;
 
 		r1 = ar1;
 		r2 = ar2;
@@ -289,13 +286,13 @@ xfs_btree_check_rec(
 int					/* error (0 or EFSCORRUPTED) */
 xfs_btree_check_sblock(
 	xfs_btree_cur_t		*cur,	/* btree cursor */
-	xfs_btree_sblock_t	*block, /* btree short form block pointer */
+	xfs_btree_sblock_t	*block,	/* btree short form block pointer */
 	int			level,	/* level of the btree block */
 	xfs_buf_t		*bp)	/* buffer containing block */
 {
 	xfs_buf_t		*agbp;	/* buffer for ag. freespace struct */
 	xfs_agf_t		*agf;	/* ag. freespace structure */
-	xfs_agblock_t		agflen; /* native ag. freespace length */
+	xfs_agblock_t		agflen;	/* native ag. freespace length */
 	int			sblock_ok; /* block passes checks */
 
 	agbp = cur->bc_private.a.agbp;
@@ -312,22 +309,13 @@ xfs_btree_check_sblock(
 		(INT_GET(block->bb_rightsib, ARCH_CONVERT) == NULLAGBLOCK ||
 		 INT_GET(block->bb_rightsib, ARCH_CONVERT) < agflen) &&
 		!INT_ISZERO(block->bb_rightsib, ARCH_CONVERT);
-	if (XFS_TEST_ERROR(!sblock_ok, cur->bc_mp,
+	if (unlikely(XFS_TEST_ERROR(!sblock_ok, cur->bc_mp,
 			XFS_ERRTAG_BTREE_CHECK_SBLOCK,
-			XFS_RANDOM_BTREE_CHECK_SBLOCK)) {
+			XFS_RANDOM_BTREE_CHECK_SBLOCK))) {
 		if (bp)
 			xfs_buftrace("SBTREE ERROR", bp);
-#ifdef __KERNEL__	/* additional, temporary, debugging code */
-		cmn_err(CE_NOTE,
-			"xfs_btree_check_sblock: Not OK:");
-		cmn_err(CE_NOTE,
-			"magic 0x%x level %d numrecs %d leftsib %d rightsib %d",
-			INT_GET(block->bb_magic, ARCH_CONVERT),
-			INT_GET(block->bb_level, ARCH_CONVERT),
-			INT_GET(block->bb_numrecs, ARCH_CONVERT),
-			INT_GET(block->bb_leftsib, ARCH_CONVERT),
-			INT_GET(block->bb_rightsib, ARCH_CONVERT));
-#endif
+		XFS_ERROR_REPORT("xfs_btree_check_sblock", XFS_ERRLEVEL_LOW,
+				 cur->bc_mp);
 		return XFS_ERROR(EFSCORRUPTED);
 	}
 	return 0;
@@ -338,7 +326,7 @@ xfs_btree_check_sblock(
  */
 int					/* error (0 or EFSCORRUPTED) */
 xfs_btree_check_sptr(
-	xfs_btree_cur_t *cur,		/* btree cursor */
+	xfs_btree_cur_t	*cur,		/* btree cursor */
 	xfs_agblock_t	ptr,		/* btree block disk address */
 	int		level)		/* btree block level */
 {
@@ -359,7 +347,7 @@ xfs_btree_check_sptr(
  */
 void
 xfs_btree_del_cursor(
-	xfs_btree_cur_t *cur,		/* btree cursor */
+	xfs_btree_cur_t	*cur,		/* btree cursor */
 	int		error)		/* del because of error */
 {
 	int		i;		/* btree level */
@@ -398,14 +386,14 @@ xfs_btree_del_cursor(
  */
 int					/* error */
 xfs_btree_dup_cursor(
-	xfs_btree_cur_t *cur,		/* input cursor */
-	xfs_btree_cur_t **ncur)		/* output cursor */
+	xfs_btree_cur_t	*cur,		/* input cursor */
+	xfs_btree_cur_t	**ncur)		/* output cursor */
 {
 	xfs_buf_t	*bp;		/* btree block's buffer pointer */
 	int		error;		/* error return value */
 	int		i;		/* level number of btree block */
 	xfs_mount_t	*mp;		/* mount structure for filesystem */
-	xfs_btree_cur_t *new;		/* new cursor value */
+	xfs_btree_cur_t	*new;		/* new cursor value */
 	xfs_trans_t	*tp;		/* transaction pointer, can be NULL */
 
 	tp = cur->bc_tp;
@@ -461,7 +449,7 @@ xfs_btree_firstrec(
 	xfs_btree_cur_t		*cur,	/* btree cursor */
 	int			level)	/* level to change */
 {
-	xfs_btree_block_t	*block; /* generic btree block pointer */
+	xfs_btree_block_t	*block;	/* generic btree block pointer */
 	xfs_buf_t		*bp;	/* buffer containing block */
 
 	/*
@@ -491,7 +479,7 @@ xfs_btree_get_block(
 	int			level,	/* level in btree */
 	xfs_buf_t		**bpp)	/* buffer containing the block */
 {
-	xfs_btree_block_t	*block; /* return value */
+	xfs_btree_block_t	*block;	/* return value */
 	xfs_buf_t		*bp;	/* return buffer */
 	xfs_ifork_t		*ifp;	/* inode fork pointer */
 	int			whichfork; /* data or attr fork */
@@ -573,7 +561,7 @@ xfs_btree_init_cursor(
 {
 	xfs_agf_t	*agf;		/* (A) allocation group freespace */
 	xfs_agi_t	*agi;		/* (I) allocation group inodespace */
-	xfs_btree_cur_t *cur;		/* return value */
+	xfs_btree_cur_t	*cur;		/* return value */
 	xfs_ifork_t	*ifp;		/* (I) inode fork pointer */
 	int		nlevels=0;	/* number of levels in the btree */
 
@@ -655,7 +643,7 @@ xfs_btree_islastblock(
 	xfs_btree_cur_t		*cur,	/* btree cursor */
 	int			level)	/* level to check */
 {
-	xfs_btree_block_t	*block; /* generic btree block pointer */
+	xfs_btree_block_t	*block;	/* generic btree block pointer */
 	xfs_buf_t		*bp;	/* buffer containing block */
 
 	block = xfs_btree_get_block(cur, level, &bp);
@@ -668,14 +656,14 @@ xfs_btree_islastblock(
 
 /*
  * Change the cursor to point to the last record in the current block
- * at the given level.	Other levels are unaffected.
+ * at the given level.  Other levels are unaffected.
  */
 int					/* success=1, failure=0 */
 xfs_btree_lastrec(
 	xfs_btree_cur_t		*cur,	/* btree cursor */
 	int			level)	/* level to change */
 {
-	xfs_btree_block_t	*block; /* generic btree block pointer */
+	xfs_btree_block_t	*block;	/* generic btree block pointer */
 	xfs_buf_t		*bp;	/* buffer containing block */
 
 	/*
