@@ -152,6 +152,7 @@ static struct {
     { offsetof(xfs_sb_t, sb_logsectlog), 0 },
     { offsetof(xfs_sb_t, sb_logsectsize),0 },
     { offsetof(xfs_sb_t, sb_logsunit),	 0 },
+    { offsetof(xfs_sb_t, sb_features2),	 0 },
     { sizeof(xfs_sb_t),			 0 }
 };
 
@@ -242,9 +243,11 @@ xfs_initialize_perag(xfs_mount_t *mp, int agcount)
 	ino = XFS_AGINO_TO_INO(mp, agcount - 1, agino);
 
 	/* Clear the mount flag if no inode can overflow 32 bits
-	 * on this filesystem.
+	 * on this filesystem, or if specifically requested..
 	 */
-	if (ino <= max_inum) {
+	if ((mp->m_flags & XFS_MOUNT_32BITINOOPT) && ino > max_inum) {
+		mp->m_flags |= XFS_MOUNT_32BITINODES;
+	} else {
 		mp->m_flags &= ~XFS_MOUNT_32BITINODES;
 	}
 
