@@ -148,7 +148,7 @@ static char *
 getstr(
 	char	**pp)
 {
-	int	c;
+	char	c;
 	char	*p;
 	char	*rval;
 
@@ -174,7 +174,7 @@ getstr(
 			return rval;
 		}
 	}
-	if (!c) {
+	if (c != '\0') {
 		fprintf(stderr, _("%s: premature EOF in prototype file\n"),
 			progname);
 		exit(1);
@@ -206,17 +206,17 @@ rsvfile(
 	libxfs_trans_ijoin(tp, ip, 0);
 	libxfs_trans_ihold(tp, ip);
 
-	ip->i_d.di_mode &= ~ISUID;
+	ip->i_d.di_mode &= ~S_ISUID;
 
 	/*
 	 * Note that we don't have to worry about mandatory
 	 * file locking being disabled here because we only
-	 * clear the ISGID bit if the Group execute bit is
+	 * clear the S_ISGID bit if the Group execute bit is
 	 * on, but if it was on then mandatory locking wouldn't
 	 * have been enabled.
 	 */
-	if (ip->i_d.di_mode & (IEXEC >> 3))
-		ip->i_d.di_mode &= ~ISGID;
+	if (ip->i_d.di_mode & S_IXGRP)
+		ip->i_d.di_mode &= ~S_ISGID;
 
 	libxfs_ichgtime(ip, XFS_ICHGTIME_MOD | XFS_ICHGTIME_CHG);
 
@@ -426,7 +426,7 @@ parseproto(
 	case '-':
 		break;
 	case 'u':
-		mode |= ISUID;
+		mode |= S_ISUID;
 		break;
 	default:
 		fprintf(stderr, _("%s: bad format string %s\n"),
@@ -437,7 +437,7 @@ parseproto(
 	case '-':
 		break;
 	case 'g':
-		mode |= ISGID;
+		mode |= S_ISGID;
 		break;
 	default:
 		fprintf(stderr, _("%s: bad format string %s\n"),
@@ -463,8 +463,8 @@ parseproto(
 	case IF_REGULAR:
 		buf = newregfile(pp, &len);
 		getres(tp, XFS_B_TO_FSB(mp, len));
-		error = libxfs_inode_alloc(&tp, pip, mode|IFREG, 1,
-					mp->m_dev, &creds, &ip);
+		error = libxfs_inode_alloc(&tp, pip, mode|S_IFREG, 1, 0,
+					&creds, &ip);
 		if (error)
 			fail(_("Inode allocation failed"), error);
 		flags |= newfile(tp, ip, &flist, &first, 0, 0, buf, len);
@@ -481,8 +481,8 @@ parseproto(
 		llen = cvtnum(mp->m_sb.sb_blocksize, mp->m_sb.sb_sectsize, value);
 		getres(tp, XFS_B_TO_FSB(mp, llen));
 
-		error = libxfs_inode_alloc(&tp, pip, mode|IFREG, 1,
-						mp->m_dev, &creds, &ip);
+		error = libxfs_inode_alloc(&tp, pip, mode|S_IFREG, 1, 0,
+						&creds, &ip);
 		if (error)
 			fail(_("Inode pre-allocation failed"), error);
 
@@ -504,8 +504,8 @@ parseproto(
 		getres(tp, 0);
 		majdev = (int)getnum(pp);
 		mindev = (int)getnum(pp);
-		error = libxfs_inode_alloc(&tp, pip, mode|IFBLK, 1,
-				makedev(majdev, mindev), &creds, &ip);
+		error = libxfs_inode_alloc(&tp, pip, mode|S_IFBLK, 1,
+				IRIX_MKDEV(majdev, mindev), &creds, &ip);
 		if (error) {
 			fail(_("Inode allocation failed"), error);
 		}
@@ -520,8 +520,8 @@ parseproto(
 		getres(tp, 0);
 		majdev = (int)getnum(pp);
 		mindev = (int)getnum(pp);
-		error = libxfs_inode_alloc(&tp, pip, mode|IFCHR, 1,
-				makedev(majdev, mindev), &creds, &ip);
+		error = libxfs_inode_alloc(&tp, pip, mode|S_IFCHR, 1,
+				IRIX_MKDEV(majdev, mindev), &creds, &ip);
 		if (error)
 			fail(_("Inode allocation failed"), error);
 		libxfs_trans_ijoin(tp, pip, 0);
@@ -533,8 +533,8 @@ parseproto(
 
 	case IF_FIFO:
 		getres(tp, 0);
-		error = libxfs_inode_alloc(&tp, pip, mode|IFIFO, 1,
-				mp->m_dev, &creds, &ip);
+		error = libxfs_inode_alloc(&tp, pip, mode|S_IFIFO, 1, 0,
+				&creds, &ip);
 		if (error)
 			fail(_("Inode allocation failed"), error);
 		libxfs_trans_ijoin(tp, pip, 0);
@@ -546,8 +546,8 @@ parseproto(
 		buf = getstr(pp);
 		len = (int)strlen(buf);
 		getres(tp, XFS_B_TO_FSB(mp, len));
-		error = libxfs_inode_alloc(&tp, pip, mode|IFLNK, 1,
-				mp->m_dev, &creds, &ip);
+		error = libxfs_inode_alloc(&tp, pip, mode|S_IFLNK, 1, 0,
+				&creds, &ip);
 		if (error)
 			fail(_("Inode allocation failed"), error);
 		flags |= newfile(tp, ip, &flist, &first, 1, 1, buf, len);
@@ -558,8 +558,8 @@ parseproto(
 		break;
 	case IF_DIRECTORY:
 		getres(tp, 0);
-		error = libxfs_inode_alloc(&tp, pip, mode|IFDIR, 1,
-				mp->m_dev, &creds, &ip);
+		error = libxfs_inode_alloc(&tp, pip, mode|S_IFDIR, 1, 0,
+				&creds, &ip);
 		if (error)
 			fail(_("Inode allocation failed"), error);
 		ip->i_d.di_nlink++;		/* account for . */
@@ -594,6 +594,8 @@ parseproto(
 		tp = NULL;
 		for (;;) {
 			name = getstr(pp);
+			if (!name)
+				break;
 			if (strcmp(name, "$") == 0)
 				break;
 			parseproto(mp, ip, pp, name);
@@ -640,8 +642,8 @@ rtinit(
 	if ((i = libxfs_trans_reserve(tp, MKFS_BLOCKRES_INODE, 0, 0, 0, 0)))
 		res_failed(i);
 	bzero(&creds, sizeof(creds));
-	error = libxfs_inode_alloc(&tp, mp->m_rootip, IFREG, 1,
-				mp->m_dev, &creds, &rbmip);
+	error = libxfs_inode_alloc(&tp, mp->m_rootip, S_IFREG, 1, 0,
+				&creds, &rbmip);
 	if (error) {
 		fail(_("Realtime bitmap inode allocation failed"), error);
 	}
@@ -658,8 +660,8 @@ rtinit(
 	libxfs_mod_sb(tp, XFS_SB_RBMINO);
 	libxfs_trans_ihold(tp, rbmip);
 	mp->m_rbmip = rbmip;
-	error = libxfs_inode_alloc(&tp, mp->m_rootip, IFREG, 1,
-				mp->m_dev, &creds, &rsumip);
+	error = libxfs_inode_alloc(&tp, mp->m_rootip, S_IFREG, 1, 0,
+				&creds, &rsumip);
 	if (error) {
 		fail(_("Realtime summary inode allocation failed"), error);
 	}
