@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2003 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2004 Silicon Graphics, Inc.  All Rights Reserved.
  * 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -166,6 +166,10 @@ char	*sopts[] = {
 	NULL
 };
 
+#define TERABYTES(count, blog)	((__uint64_t)(count) << (40 - (blog)))
+#define GIGABYTES(count, blog)	((__uint64_t)(count) << (30 - (blog)))
+#define MEGABYTES(count, blog)	((__uint64_t)(count) << (20 - (blog)))
+
 /*
  * Use this macro before we have superblock and mount structure
  */
@@ -181,6 +185,11 @@ char	*sopts[] = {
 	((uint)(MKFS_BLOCKRES_INODE + XFS_DA_NODE_MAXDEPTH + \
 	(XFS_BM_MAXLEVELS(mp, XFS_DATA_FORK) - 1) + (rb)))
 
+/* amount (in bytes) we zero at the beginning and end of the device to
+ * remove traces of other filesystems, raid superblocks, etc.
+ */
+#define WHACK_SIZE (128 * 1024)
+
 static void
 calc_stripe_factors(
 	int		dsu,
@@ -295,11 +304,16 @@ fixup_log_stripe(
 	__uint64_t	agsize,
 	int		sunit,
 	xfs_drfsbno_t	*logblocks,
-	int		blocklog)
+	int		blocklog,
+	int		*lalign)
 {
 	__uint64_t	tmp_logblocks;
 
-	logstart = ((logstart + (sunit - 1))/sunit) * sunit;
+	if ((logstart % sunit) != 0) {
+		logstart = ((logstart + (sunit - 1))/sunit) * sunit;
+		*lalign = 1;
+	}
+
 	/* 
 	 * Make sure that the log size is a multiple of the
 	 * stripe unit
@@ -336,6 +350,136 @@ fixup_log_stripe(
 	return logstart;
 }
 
+void
+calc_default_ag_geometry(
+	int		blocklog,
+	__uint64_t	dblocks,
+	__uint64_t	*agsize,
+	__uint64_t	*agcount)
+{
+	__uint64_t	blocks;
+	__uint64_t	count = 0;
+	int		shift = 0;
+
+	/*
+	 * First handle the extremes - the points at which we will
+	 * always use the maximum AG size, the points at which we
+	 * always use the minimum, and a "small-step" for 16-128Mb.
+	 */
+	if (dblocks >= TERABYTES(64, blocklog)) {
+		blocks = XFS_AG_MAX_BLOCKS(blocklog);
+		goto done;
+	} else if (dblocks < MEGABYTES(16, blocklog)) {
+		blocks = dblocks;
+		count = 1;
+		goto done;
+	} else if (dblocks < MEGABYTES(128, blocklog)) {
+		blocks = MEGABYTES(16, blocklog);
+		goto done;
+	}
+
+	/*
+	 * For the remainder we choose an AG size based on the
+	 * number of data blocks available, trying to keep the
+	 * number of AGs relatively small (especially compared
+	 * to the original algorithm).  AG count is calculated
+	 * based on the prefered AG size, not vice-versa - the
+	 * count can be increased by growfs, so prefer to use
+	 * smaller counts at mkfs time.
+	 * 
+	 * This scales us up smoothly between min/max AG sizes.
+	 */
+	if (dblocks > GIGABYTES(512, blocklog))
+		shift = 5;
+	else if (dblocks > GIGABYTES(8, blocklog))
+		shift = 4;
+	else if (dblocks >= MEGABYTES(128, blocklog))
+		shift = 3;
+	else
+		ASSERT(0);
+	blocks = dblocks >> shift;
+
+done:
+	if (!count)
+		count = dblocks / blocks + (dblocks % blocks != 0);
+	*agsize = blocks;
+	*agcount = count;
+}
+
+static void
+validate_ag_geometry(
+	int		blocklog,
+	__uint64_t	dblocks,
+	__uint64_t	agsize,
+	__uint64_t	agcount)
+{
+	if (agsize < XFS_AG_MIN_BLOCKS(blocklog)) {
+		fprintf(stderr,
+	_("agsize (%lldb) too small, need at least %lld blocks\n"),
+			(long long)agsize,
+			(long long)XFS_AG_MIN_BLOCKS(blocklog));
+		usage();
+	}
+
+	if (agsize > XFS_AG_MAX_BLOCKS(blocklog)) {
+		fprintf(stderr,
+	_("agsize (%lldb) too big, maximum is %lld blocks\n"),
+			(long long)agsize,
+			(long long)XFS_AG_MAX_BLOCKS(blocklog));
+		usage();
+	}
+
+	if (agsize > dblocks) {
+		fprintf(stderr,
+	_("agsize (%lldb) too big, data area is %lld blocks\n"),
+			(long long)agsize, (long long)dblocks);
+			usage();
+	}
+
+	if (agsize < XFS_AG_MIN_BLOCKS(blocklog)) {
+		fprintf(stderr,
+	_("too many allocation groups for size = %lld\n"),
+				(long long)agsize);
+		fprintf(stderr, _("need at most %lld allocation groups\n"),
+			(long long)(dblocks / XFS_AG_MIN_BLOCKS(blocklog) +
+				(dblocks % XFS_AG_MIN_BLOCKS(blocklog) != 0)));
+		usage();
+	}
+
+	if (agsize > XFS_AG_MAX_BLOCKS(blocklog)) {
+		fprintf(stderr,
+	_("too few allocation groups for size = %lld\n"), (long long)agsize);
+		fprintf(stderr,
+	_("need at least %lld allocation groups\n"),
+		(long long)(dblocks / XFS_AG_MAX_BLOCKS(blocklog) + 
+			(dblocks % XFS_AG_MAX_BLOCKS(blocklog) != 0)));
+		usage();
+	}
+
+	/*
+	 * If the last AG is too small, reduce the filesystem size
+	 * and drop the blocks.
+	 */
+	if ( dblocks % agsize != 0 &&
+	     (dblocks % agsize < XFS_AG_MIN_BLOCKS(blocklog))) {
+		fprintf(stderr,
+	_("last AG size %lld blocks too small, minimum size is %lld blocks\n"),
+			(long long)(dblocks % agsize),
+			(long long)XFS_AG_MIN_BLOCKS(blocklog));
+		usage();
+	}
+
+	/*
+	 * If agcount is too large, make it smaller.
+	 */
+	if (agcount > XFS_MAX_AGNUMBER + 1) {
+		fprintf(stderr,
+	_("%lld allocation groups is too many, maximum is %lld\n"),
+			(long long)agcount, (long long)XFS_MAX_AGNUMBER + 1);
+		usage();
+	}
+}
+
 int
 main(
 	int			argc,
@@ -436,7 +580,6 @@ main(
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
 
-	agcount = 8;
 	blflag = bsflag = slflag = ssflag = lslflag = lssflag = 0;
 	blocklog = blocksize = 0;
 	sectorlog = lsectorlog = XFS_MIN_SECTORSIZE_LOG;
@@ -462,6 +605,7 @@ main(
 	bzero(&xi, sizeof(xi));
 	xi.notvolok = 1;
 	xi.setblksize = 1;
+	xi.isreadonly = LIBXFS_EXCLUSIVELY;
 
 	while ((c = getopt(argc, argv, "b:d:i:l:L:n:Np:qr:s:CfV")) != EOF) {
 		switch (c) {
@@ -1131,9 +1275,6 @@ main(
 		usage();
 	}
 
-	if (!daflag)
-		agcount = 8;
-
 	if (xi.disfile && (!dsize || !xi.dname)) {
 		fprintf(stderr,
 	_("if -d file then -d name and -d size are required\n"));
@@ -1483,10 +1624,9 @@ _("size %s specified for log subvolume is too large, maximum is %lld blocks\n"),
 		nbmblocks = 0;
 	}
 
-	if (dasize) {
+	if (dasize) {		/* User-specified AG size */
 		/*
-		 * If the specified agsize isn't a multiple of fs blks,
-		 * complain.
+		 * Check specified agsize is a multiple of blocksize.
 		 */
 		if (agsize % blocksize) {
 			fprintf(stderr,
@@ -1494,86 +1634,13 @@ _("size %s specified for log subvolume is too large, maximum is %lld blocks\n"),
 				(long long)agsize, blocksize);
 			usage();
 		}
-
 		agsize /= blocksize;
-
-		/*
-		 * If the specified agsize is too small, or too large,
-		 * complain.
-		 */
-		if (agsize < XFS_AG_MIN_BLOCKS(blocklog)) {
-			fprintf(stderr,
-		_("agsize (%lldb) too small, need at least %lld blocks\n"),
-				(long long)agsize,
-				(long long)XFS_AG_MIN_BLOCKS(blocklog));
-			usage();
-		}
-
-		if (agsize > XFS_AG_MAX_BLOCKS(blocklog)) {
-			fprintf(stderr,
-		_("agsize (%lldb) too big, maximum is %lld blocks\n"),
-				(long long)agsize,
-				(long long)XFS_AG_MAX_BLOCKS(blocklog));
-			usage();
-		}
-
-		if (agsize > dblocks)  {
-			fprintf(stderr,
-		_("agsize (%lldb) too big, data area is %lld blocks\n"),
-				(long long)agsize, (long long)dblocks);
-			usage();
-		}
-
 		agcount = dblocks / agsize + (dblocks % agsize != 0);
-	} else {
+
+	} else if (daflag)	/* User-specified AG size */
 		agsize = dblocks / agcount + (dblocks % agcount != 0);
-	}
-
-	/*
-	 * If the ag size is too small, complain if agcount/agsize was
-	 * specified, and fix it otherwise.
-	 */
-	if (agsize < XFS_AG_MIN_BLOCKS(blocklog)) {
-		if (daflag || dasize) {
-			fprintf(stderr,
-			_("too many allocation groups for size = %lld\n"),
-				(long long)agsize);
-			fprintf(stderr,
-				_("need at most %lld allocation groups\n"),
-				(long long)
-				(dblocks / XFS_AG_MIN_BLOCKS(blocklog) +
-				(dblocks % XFS_AG_MIN_BLOCKS(blocklog) != 0)));
-			usage();
-		}
-		agsize = XFS_AG_MIN_BLOCKS(blocklog);
-		if (dblocks < agsize) {
-			agcount = 1;
-			agsize = dblocks;
-		} else {
-			agcount = dblocks / agsize;
-			agsize = dblocks / agcount +(dblocks % agcount != 0);
-		}
-	}
-
-	/*
-	 * If the ag size is too large, complain if agcount/agsize was
-	 * specified, and fix it otherwise.
-	 */
-	else if (agsize > XFS_AG_MAX_BLOCKS(blocklog)) {
-		if (daflag || dasize) {
-			fprintf(stderr,
-			_("too few allocation groups for size = %lld\n"),
-				(long long)agsize);
-			fprintf(stderr,
-				_("need at least %lld allocation groups\n"),
-				(long long)
-				(dblocks / XFS_AG_MAX_BLOCKS(blocklog) + 
-				(dblocks % XFS_AG_MAX_BLOCKS(blocklog) != 0)));
-			usage();
-		}
-		agsize = XFS_AG_MAX_BLOCKS(blocklog);
-		agcount = dblocks / agsize + (dblocks % agsize != 0);
-	}
+	else
+		calc_default_ag_geometry(blocklog, dblocks, &agsize, &agcount);
 
 	/*
 	 * If the last AG is too small, reduce the filesystem size
@@ -1586,48 +1653,7 @@ _("size %s specified for log subvolume is too large, maximum is %lld blocks\n"),
 		ASSERT(agcount != 0);
 	}
 
-	/*
-	 * If agcount was not specified, and agsize is larger than
-	 * we'd like, make it the size we want.
-	 */
-	if (!daflag && !dasize &&
-	    (agsize > XFS_AG_BEST_BLOCKS(blocklog,dblocks))) {
-		agsize = XFS_AG_BEST_BLOCKS(blocklog,dblocks);
-		agcount = dblocks / agsize + (dblocks % agsize != 0);
-		/*
-		 * If the last AG is too small, reduce the filesystem size
-		 * and drop the blocks.
-		 */
-		if ( dblocks % agsize != 0 &&
-		    (dblocks % agsize < XFS_AG_MIN_BLOCKS(blocklog))) {
-			dblocks = (xfs_drfsbno_t)((agcount - 1) * agsize);
-			agcount--;
-			ASSERT(agcount != 0);
-		}
-	}
-
-	/*
-	 * If agcount is too large, make it smaller.
-	 */
-	if (agcount > XFS_MAX_AGNUMBER + 1) {
-		agcount = XFS_MAX_AGNUMBER + 1;
-		agsize = dblocks / agcount + (dblocks % agcount != 0);
-
-		if (dasize || daflag)
-			fprintf(stderr,
-		_("agsize set to %lld, agcount %lld > max (%lld)\n"),
-				(long long)agsize, (long long)agcount,
-				(long long)XFS_MAX_AGNUMBER+1);
-
-		if (agsize > XFS_AG_MAX_BLOCKS(blocklog)) {
-			/*
-			 * We're confused.
-			 */
-			fprintf(stderr, _("%s: can't compute agsize/agcount\n"),
-				progname);
-			exit(1);
-		}
-	}
+	validate_ag_geometry(blocklog, dblocks, agsize, agcount);
 
 	xlv_dsunit = xlv_dswidth = 0;
 	if (!xi.disfile)
@@ -1772,7 +1798,7 @@ an AG size that is one stripe unit smaller, for example %llu.\n"),
 		fprintf(stderr,
 	_("log stripe unit (%d bytes) is too large (maximum is 256KiB)\n"),
 			(lsunit * blocksize));
-		lsunit = 32 * 1024;
+		lsunit = (32 * 1024) >> blocklog;
 		fprintf(stderr, _("log stripe unit adjusted to 32KiB\n"));
 	}
 
@@ -1816,15 +1842,14 @@ an AG size that is one stripe unit smaller, for example %llu.\n"),
 		/*
 		 * Align the logstart at stripe unit boundary.
 		 */
-		if (lsunit && ((logstart % lsunit) != 0)) {
+		if (lsunit) {
 			logstart = fixup_log_stripe(mp, lsflag, logstart,
-					agsize, lsunit, &logblocks, blocklog);
-			lalign = 1;
-		} else if (dsunit && ((logstart % dsunit) != 0)) {
+					agsize, lsunit, &logblocks, blocklog,
+					&lalign);
+		} else if (dsunit) {
 			logstart = fixup_log_stripe(mp, lsflag, logstart,
-					agsize, dsunit, &logblocks,
-					blocklog);
-			lalign = 1;
+					agsize, dsunit, &logblocks, blocklog,
+					&lalign);
 		}
 	} else
 		logstart = 0;
@@ -1911,16 +1936,16 @@ an AG size that is one stripe unit smaller, for example %llu.\n"),
 	sbp->sb_versionnum =
 		XFS_SB_VERSION_MKFS(iaflag, dsunit != 0, extent_flagging,
 			dirversion == 2, logversion == 2,
-			(sectorsize != BBSIZE || lsectorsize != BBSIZE));
-
+			(sectorsize != BBSIZE || lsectorsize != BBSIZE), 0);
+	sbp->sb_features2 = XFS_SB_VERSION2_MKFS(0);
 	/*
-	 * Zero out the first 68k in on the device, to obliterate any old 
+	 * Zero out the beginning of the device, to obliterate any old 
 	 * filesystem signatures out there.  This should take care of 
 	 * swap (somewhere around the page size), jfs (32k), 
 	 * ext[2,3] and reiserfs (64k) - and hopefully all else.
 	 */
-	buf = libxfs_getbuf(xi.ddev, 0, 136);
-	bzero(XFS_BUF_PTR(buf), 136*BBSIZE);
+	buf = libxfs_getbuf(xi.ddev, 0, BTOBB(WHACK_SIZE));
+	bzero(XFS_BUF_PTR(buf), WHACK_SIZE);
 	libxfs_writebuf(buf, LIBXFS_EXIT_ON_FAILURE);
 
 	/* OK, now write the superblock */
@@ -1936,19 +1961,20 @@ an AG size that is one stripe unit smaller, for example %llu.\n"),
 	 * will succeed.
 	 */
 	if (xi.disfile && ftruncate64(xi.dfd, dblocks * blocksize) < 0) {
-		fprintf(stderr, _("%s: Growing the data section file failed\n"),
+		fprintf(stderr, _("%s: Growing the data section failed\n"),
 			progname);
 		exit(1);
 	}
 
 	/*
-	 * Zero out the last 64k on the device, to obliterate any
+	 * Zero out the end of the device, to obliterate any
 	 * old MD RAID (or other) metadata at the end of the device.
+ 	 * (MD sb is ~64k from the end, take out a wider swath to be sure)
 	 */
 	if (!xi.disfile) {
-		buf = libxfs_getbuf(xi.ddev, (xi.dsize - BTOBB(65536)), 
-				    BTOBB(65536));
-		bzero(XFS_BUF_PTR(buf), 65536);
+		buf = libxfs_getbuf(xi.ddev, (xi.dsize - BTOBB(WHACK_SIZE)), 
+				    BTOBB(WHACK_SIZE));
+		bzero(XFS_BUF_PTR(buf), WHACK_SIZE);
 		libxfs_writebuf(buf, LIBXFS_EXIT_ON_FAILURE);
 	}
 
@@ -2067,6 +2093,7 @@ an AG size that is one stripe unit smaller, for example %llu.\n"),
 			if (lalign) {
 				/*
 				 * Have to insert two records
+				 * Insert pad record for stripe align of log
 				 */
 				INT_SET(arec->ar_blockcount, ARCH_CONVERT, 
 					(xfs_extlen_t)(XFS_FSB_TO_AGBNO(
@@ -2074,6 +2101,9 @@ an AG size that is one stripe unit smaller, for example %llu.\n"),
 				  	- (INT_GET(arec->ar_startblock,
 						ARCH_CONVERT))));
 				nrec = arec + 1;
+				/*
+				 * Insert record at start of internal log
+				 */
 				INT_SET(nrec->ar_startblock, ARCH_CONVERT,
 					INT_GET(arec->ar_startblock,
 						ARCH_CONVERT) +
@@ -2082,6 +2112,9 @@ an AG size that is one stripe unit smaller, for example %llu.\n"),
 				arec = nrec;
 				INT_MOD(block->bb_numrecs, ARCH_CONVERT, 1);
 			} 
+			/*
+			 * Change record start to after the internal log
+			 */
 			INT_MOD(arec->ar_startblock, ARCH_CONVERT, logblocks);
 		} 
 		INT_SET(arec->ar_blockcount, ARCH_CONVERT,
