@@ -66,7 +66,7 @@ calc_attr_offset(xfs_mount_t *mp, xfs_dinode_t *dino)
 	 */
 	switch (dinoc->di_format)  {
 	case XFS_DINODE_FMT_DEV:
-		offset += sizeof(dev_t);
+		offset += sizeof(xfs_dev_t);
 		break;
 	case XFS_DINODE_FMT_LOCAL:
 		offset += INT_GET(dinoc->di_size, ARCH_CONVERT);
@@ -525,6 +525,7 @@ process_bmbt_reclist_int(
 	int			i;
 	int			state;
 	int			flag;		/* extent flag */
+	int			pwe;		/* partially-written extent */
 
 	if (whichfork == XFS_DATA_FORK)
 		forkname = _("data");
@@ -633,9 +634,16 @@ process_bmbt_reclist_int(
 			 */
 			for (b = s; b < s + c; b += mp->m_sb.sb_rextsize)  {
 				ext = (xfs_drtbno_t) b / mp->m_sb.sb_rextsize;
+				if (XFS_SB_VERSION_HASEXTFLGBIT(&mp->m_sb) &&
+				    flag && (b % mp->m_sb.sb_rextsize != 0)) {
+					pwe = 1;
+				} else {
+					pwe = 0;
+				}
 
 				if (check_dups == 1)  {
-					if (search_rt_dup_extent(mp, ext))  {
+					if (search_rt_dup_extent(mp, ext) &&
+					    !pwe)  {
 						do_warn(
 	_("data fork in rt ino %llu claims dup rt extent, off - %llu, "
 	  "start - %llu, count %llu\n"),
@@ -671,6 +679,8 @@ process_bmbt_reclist_int(
 	_("%s fork in rt inode %llu found metadata block %llu in %s bmap\n"),
 						forkname, ino, ext, ftype);
 				case XR_E_INUSE:
+					if (pwe)
+						break;
 				case XR_E_MULT:
 					set_rtbno_state(mp, ext, XR_E_MULT);
 					do_warn(
@@ -1904,10 +1914,10 @@ process_dinode_int(xfs_mount_t *mp,
 	 * as we reset the inode when we re-use it.
 	 */
 	if (INT_GET(dinoc->di_mode, ARCH_CONVERT) != 0 &&
-		((((INT_GET(dinoc->di_mode, ARCH_CONVERT) & IFMT) >> 12) > 15) ||
+		((((INT_GET(dinoc->di_mode, ARCH_CONVERT) & S_IFMT) >> 12) > 15) ||
 		dinoc->di_format < XFS_DINODE_FMT_DEV ||
 		dinoc->di_format > XFS_DINODE_FMT_UUID ||
-			(!(okfmts[(INT_GET(dinoc->di_mode, ARCH_CONVERT) & IFMT) >> 12] &
+			(!(okfmts[(INT_GET(dinoc->di_mode, ARCH_CONVERT) & S_IFMT) >> 12] &
 			  (1 << dinoc->di_format))))) {
 		/* bad inode format */
 		retval++;
@@ -1941,12 +1951,12 @@ process_dinode_int(xfs_mount_t *mp,
 
 	/* set type and map type info */
 
-	switch (INT_GET(dinoc->di_mode, ARCH_CONVERT) & IFMT) {
-	case IFDIR:
+	switch (INT_GET(dinoc->di_mode, ARCH_CONVERT) & S_IFMT) {
+	case S_IFDIR:
 		type = XR_INO_DIR;
 		*isa_dir = 1;
 		break;
-	case IFREG:
+	case S_IFREG:
 		if (INT_GET(dinoc->di_flags, ARCH_CONVERT) & XFS_DIFLAG_REALTIME)
 			type = XR_INO_RTDATA;
 		else if (lino == mp->m_sb.sb_rbmino)
@@ -1956,28 +1966,25 @@ process_dinode_int(xfs_mount_t *mp,
 		else
 			type = XR_INO_DATA;
 		break;
-	case IFLNK:
+	case S_IFLNK:
 		type = XR_INO_SYMLINK;
 		break;
-	case IFCHR:
+	case S_IFCHR:
 		type = XR_INO_CHRDEV;
 		break;
-	case IFBLK:
+	case S_IFBLK:
 		type = XR_INO_BLKDEV;
 		break;
-	case IFSOCK:
+	case S_IFSOCK:
 		type = XR_INO_SOCK;
 		break;
-	case IFIFO:
+	case S_IFIFO:
 		type = XR_INO_FIFO;
 		break;
-	case IFMNT:
-		type = XR_INO_MOUNTPOINT;
-		break;
 	default:
 		type = XR_INO_UNKNOWN;
 		do_warn(_("Unexpected inode type %#o inode %llu\n"),
-			(int) (INT_GET(dinoc->di_mode, ARCH_CONVERT) & IFMT), lino);
+			(int) (INT_GET(dinoc->di_mode, ARCH_CONVERT) & S_IFMT), lino);
 		abort();
 		break;
 	}
@@ -1992,9 +1999,9 @@ process_dinode_int(xfs_mount_t *mp,
 		if (!no_modify)  {
 			do_warn(_("resetting to directory\n"));
 			INT_MOD_EXPR(dinoc->di_mode, ARCH_CONVERT,
-			  &= ~(INT_GET(dinoc->di_mode, ARCH_CONVERT) & IFMT));
+			  &= ~(INT_GET(dinoc->di_mode, ARCH_CONVERT) & S_IFMT));
 			INT_MOD_EXPR(dinoc->di_mode, ARCH_CONVERT,
-			  |= INT_GET(dinoc->di_mode, ARCH_CONVERT) & IFDIR);
+			  |= INT_GET(dinoc->di_mode, ARCH_CONVERT) & S_IFDIR);
 		} else  {
 			do_warn(_("would reset to directory\n"));
 		}
@@ -2009,7 +2016,7 @@ process_dinode_int(xfs_mount_t *mp,
 	} else if (lino == mp->m_sb.sb_uquotino)  {
 		if (type != XR_INO_DATA)  {
 			do_warn(_("user quota inode has bad type 0x%x\n"),
-				INT_GET(dinoc->di_mode, ARCH_CONVERT) & IFMT);
+				INT_GET(dinoc->di_mode, ARCH_CONVERT) & S_IFMT);
 
 			if (!no_modify)  {
 				*dirty += clear_dinode(mp, dino, lino);
@@ -2027,7 +2034,7 @@ process_dinode_int(xfs_mount_t *mp,
 	} else if (lino == mp->m_sb.sb_gquotino)  {
 		if (type != XR_INO_DATA)  {
 			do_warn(_("group quota inode has bad type 0x%x\n"),
-				INT_GET(dinoc->di_mode, ARCH_CONVERT) & IFMT);
+				INT_GET(dinoc->di_mode, ARCH_CONVERT) & S_IFMT);
 
 			if (!no_modify)  {
 				*dirty += clear_dinode(mp, dino, lino);
@@ -2053,9 +2060,9 @@ process_dinode_int(xfs_mount_t *mp,
 		if (!no_modify)  {
 			do_warn(_("resetting to regular file\n"));
 			INT_MOD_EXPR(dinoc->di_mode, ARCH_CONVERT,
-			  &= ~(INT_GET(dinoc->di_mode, ARCH_CONVERT) & IFMT));
+			  &= ~(INT_GET(dinoc->di_mode, ARCH_CONVERT) & S_IFMT));
 			INT_MOD_EXPR(dinoc->di_mode, ARCH_CONVERT,
-			  |= INT_GET(dinoc->di_mode, ARCH_CONVERT) & IFREG);
+			  |= INT_GET(dinoc->di_mode, ARCH_CONVERT) & S_IFREG);
 		} else  {
 			do_warn(_("would reset to regular file\n"));
 		}
@@ -2283,12 +2290,12 @@ _("mismatch between format (%d) and size (%lld) in directory ino %llu\n"),
 		switch (dinoc->di_format)  {
 		case XFS_DINODE_FMT_DEV:
 			if (dinoc->di_forkoff !=
-					(roundup(sizeof(dev_t), 8) >> 3))  {
+					(roundup(sizeof(xfs_dev_t), 8) >> 3))  {
 				do_warn(
 		_("bad attr fork offset %d in dev inode %llu, should be %d\n"),
 					(int) dinoc->di_forkoff,
 					lino,
-					(int) (roundup(sizeof(dev_t), 8) >> 3));
+					(int) (roundup(sizeof(xfs_dev_t), 8) >> 3));
 				err = 1;
 			}
 			break;
