@@ -1,37 +1,36 @@
 /*
  * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
 #include <libxfs.h>
-#include <malloc.h>
 #include "avl.h"
 #include "globals.h"
 #include "incore.h"
@@ -74,17 +73,17 @@ setup_bmap(xfs_agnumber_t agno, xfs_agblock_t numblocks, xfs_drtbno_t rtblocks)
 	int i;
 	size_t size = 0;
 
-        ba_bmap = (__uint64_t**)malloc(agno*sizeof(__uint64_t *));
-        if (!ba_bmap)  {
-		do_error("couldn't allocate block map pointers\n");
+	ba_bmap = (__uint64_t**)malloc(agno*sizeof(__uint64_t *));
+	if (!ba_bmap)  {
+		do_error(_("couldn't allocate block map pointers\n"));
 		return;
 	}
 	for (i = 0; i < agno; i++)  {
-                size = roundup(numblocks / (NBBY/XR_BB),sizeof(__uint64_t));
-                
-                ba_bmap[i] = (__uint64_t*)memalign(sizeof(__uint64_t), size);
-                if (!ba_bmap[i]) {
-			do_error("couldn't allocate block map, size = %d\n",
+		size = roundup(numblocks / (NBBY/XR_BB),sizeof(__uint64_t));
+
+		ba_bmap[i] = (__uint64_t*)memalign(sizeof(__uint64_t), size);
+		if (!ba_bmap[i]) {
+			do_error(_("couldn't allocate block map, size = %d\n"),
 				numblocks);
 			return;
 		}
@@ -98,10 +97,10 @@ setup_bmap(xfs_agnumber_t agno, xfs_agblock_t numblocks, xfs_drtbno_t rtblocks)
 
 	size = roundup(rtblocks / (NBBY/XR_BB), sizeof(__uint64_t));
 
-        rt_ba_bmap=(__uint64_t*)memalign(sizeof(__uint64_t), size);
+	rt_ba_bmap=(__uint64_t*)memalign(sizeof(__uint64_t), size);
 	if (!rt_ba_bmap) {
 			do_error(
-			"couldn't allocate real-time block map, size = %llu\n",
+		_("couldn't allocate realtime block map, size = %llu\n"),
 				rtblocks);
 			return;
 	}
@@ -180,7 +179,7 @@ set_bmap_rt(xfs_drtbno_t num)
 
 	for (j = 0; j < size; j++)
 		rt_ba_bmap[j] = 0x2222222222222222LL;
-	
+
 	return;
 }
 
