@@ -1,32 +1,32 @@
 /*
  * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
@@ -122,7 +122,8 @@ mk_extent_tree_nodes(xfs_agblock_t new_startblock,
 		ASSERT(ext_flist.list == NULL);
 
 		if ((rec = malloc(sizeof(extent_alloc_rec_t))) == NULL)
-			do_error("couldn't allocate new extent descriptors.\n");
+			do_error(
+			_("couldn't allocate new extent descriptors.\n"));
 
 		record_allocation(&rec->alloc_rec, ba_list);
 
@@ -251,7 +252,7 @@ add_bno_extent(xfs_agnumber_t agno, xfs_agblock_t startblock,
 	ext = mk_extent_tree_nodes(startblock, blockcount, XR_E_FREE);
 
 	if (avl_insert(extent_bno_ptrs[agno], (avlnode_t *) ext) == NULL)  {
-		do_error("xfs_repair:  duplicate bno extent range\n");
+		do_error(_("duplicate bno extent range\n"));
 	}
 }
 
@@ -367,7 +368,7 @@ add_bcnt_extent(xfs_agnumber_t agno, xfs_agblock_t startblock,
 	}
 
 	if (avl_insert(extent_bcnt_ptrs[agno], (avlnode_t *) ext) == NULL)  {
-		do_error("xfs_repair:  duplicate bno extent range\n");
+		do_error(_(":  duplicate bno extent range\n"));
 	}
 
 	return;
@@ -439,7 +440,7 @@ get_bcnt_extent(xfs_agnumber_t agno, xfs_agblock_t startblock,
 	if ((ext = (extent_tree_node_t *) avl_find(extent_bcnt_ptrs[agno],
 							blockcount)) == NULL)
 		return(NULL);
-	
+
 	top = ext;
 
 	if (ext->next != NULL)  {
@@ -462,7 +463,7 @@ get_bcnt_extent(xfs_agnumber_t agno, xfs_agblock_t startblock,
 			 * is the head of the list so pulling
 			 * the item out of the list and hence
 			 * the avl tree would be a bad idea.
-			 * 
+			 *
 			 * (cheaper than the alternative, a tree
 			 * delete of this node followed by a tree
 			 * insert of the next node on the list).
@@ -529,7 +530,7 @@ add_dup_extent(xfs_agnumber_t agno, xfs_agblock_t startblock,
 
 		if (avl_insert(extent_tree_ptrs[agno],
 				(avlnode_t *) ext) == NULL)  {
-			do_error("xfs_repair:  duplicate extent range\n");
+			do_error(_("duplicate extent range\n"));
 		}
 
 		return;
@@ -554,7 +555,7 @@ add_dup_extent(xfs_agnumber_t agno, xfs_agblock_t startblock,
 		/*
 		 * just bail if the new extent is contained within an old one
 		 */
-		if (ext->ex_startblock <= startblock && 
+		if (ext->ex_startblock <= startblock &&
 				ext->ex_blockcount >= blockcount)
 			return;
 		/*
@@ -580,7 +581,7 @@ add_dup_extent(xfs_agnumber_t agno, xfs_agblock_t startblock,
 	ext = mk_extent_tree_nodes(new_startblock, new_blockcount, XR_E_MULT);
 
 	if (avl_insert(extent_tree_ptrs[agno], (avlnode_t *) ext) == NULL)  {
-		do_error("xfs_repair:  duplicate extent range\n");
+		do_error(_("duplicate extent range\n"));
 	}
 
 	return;
@@ -666,7 +667,8 @@ mk_rt_extent_tree_nodes(xfs_drtbno_t new_startblock,
 		ASSERT(rt_ext_flist.list == NULL);
 
 		if ((rec = malloc(sizeof(rt_extent_alloc_rec_t))) == NULL)
-			do_error("couldn't allocate new extent descriptors.\n");
+			do_error(
+			_("couldn't allocate new extent descriptors.\n"));
 
 		record_allocation(&rec->alloc_rec, rt_ba_list);
 
@@ -779,7 +781,7 @@ add_rt_dup_extent(xfs_drtbno_t startblock, xfs_extlen_t blockcount)
 
 		if (avl64_insert(rt_ext_tree_ptr,
 				(avl64node_t *) ext) == NULL)  {
-			do_error("xfs_repair:  duplicate extent range\n");
+			do_error(_("duplicate extent range\n"));
 		}
 
 		return;
@@ -804,7 +806,7 @@ add_rt_dup_extent(xfs_drtbno_t startblock, xfs_extlen_t blockcount)
 		/*
 		 * just bail if the new extent is contained within an old one
 		 */
-		if (ext->rt_startblock <= startblock && 
+		if (ext->rt_startblock <= startblock &&
 				ext->rt_blockcount >= blockcount)
 			return;
 		/*
@@ -831,7 +833,7 @@ add_rt_dup_extent(xfs_drtbno_t startblock, xfs_extlen_t blockcount)
 				new_blockcount, XR_E_MULT);
 
 	if (avl64_insert(rt_ext_tree_ptr, (avl64node_t *) ext) == NULL)  {
-		do_error("xfs_repair:  duplicate extent range\n");
+		do_error(_("duplicate extent range\n"));
 	}
 
 	return;
@@ -879,26 +881,32 @@ incore_ext_init(xfs_mount_t *mp)
 
 	if ((extent_tree_ptrs = malloc(agcount *
 					sizeof(avltree_desc_t *))) == NULL)
-		do_error("couldn't malloc dup extent tree descriptor table\n");
+		do_error(
+	_("couldn't malloc dup extent tree descriptor table\n"));
 
 	if ((extent_bno_ptrs = malloc(agcount *
 					sizeof(avltree_desc_t *))) == NULL)
-		do_error("couldn't malloc free by-bno extent tree descriptor table\n");
+		do_error(
+	_("couldn't malloc free by-bno extent tree descriptor table\n"));
 
 	if ((extent_bcnt_ptrs = malloc(agcount *
 					sizeof(avltree_desc_t *))) == NULL)
-		do_error("couldn't malloc free by-bcnt extent tree descriptor table\n");
+		do_error(
+	_("couldn't malloc free by-bcnt extent tree descriptor table\n"));
 
 	for (i = 0; i < agcount; i++)  {
 		if ((extent_tree_ptrs[i] =
 				malloc(sizeof(avltree_desc_t))) == NULL)
-			do_error("couldn't malloc dup extent tree descriptor\n");
+			do_error(
+			_("couldn't malloc dup extent tree descriptor\n"));
 		if ((extent_bno_ptrs[i] =
 				malloc(sizeof(avltree_desc_t))) == NULL)
-			do_error("couldn't malloc bno extent tree descriptor\n");
+			do_error(
+			_("couldn't malloc bno extent tree descriptor\n"));
 		if ((extent_bcnt_ptrs[i] =
 				malloc(sizeof(avltree_desc_t))) == NULL)
-			do_error("couldn't malloc bcnt extent tree descriptor\n");
+			do_error(
+			_("couldn't malloc bcnt extent tree descriptor\n"));
 	}
 
 	for (i = 0; i < agcount; i++)  {
@@ -908,7 +916,7 @@ incore_ext_init(xfs_mount_t *mp)
 	}
 
 	if ((rt_ext_tree_ptr = malloc(sizeof(avltree_desc_t))) == NULL)
-		do_error("couldn't malloc dup rt extent tree descriptor\n");
+		do_error(_("couldn't malloc dup rt extent tree descriptor\n"));
 
 	avl64_init_tree(rt_ext_tree_ptr, &avl64_extent_tree_ops);
 
