@@ -1,32 +1,32 @@
 /*
  * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
@@ -226,10 +226,8 @@ setup_cursor(xfs_mount_t *mp, xfs_agnumber_t agno, bt_status_t *curs)
 	ASSERT(big_extent_len > 0);
 
 	if ((curs->btree_blocks = malloc(sizeof(xfs_agblock_t *)
-					* big_extent_len)) == NULL)  {
-		do_error("could not set up btree block array\n");
-		exit(1);
-	}
+					* big_extent_len)) == NULL)
+		do_error(_("could not set up btree block array\n"));
 
 	agb_ptr = curs->free_btree_blocks = curs->btree_blocks;
 
@@ -240,10 +238,8 @@ setup_cursor(xfs_mount_t *mp, xfs_agnumber_t agno, bt_status_t *curs)
 	 * grab the smallest extent and use it up, then get the
 	 * next smallest.  This mimics the init_*_cursor code.
 	 */
-	if ((ext_ptr =  findfirst_bcnt_extent(agno)) == NULL)  {
-		do_error("error - not enough free space in filesystem\n");
-		exit(1);
-	}
+	if ((ext_ptr =  findfirst_bcnt_extent(agno)) == NULL)
+		do_error(_("error - not enough free space in filesystem\n"));
 
 	agb_ptr = curs->btree_blocks;
 	j = curs->level[0].num_blocks;
@@ -445,7 +441,7 @@ calculate_freespace_cursor(xfs_mount_t *mp, xfs_agnumber_t agno,
 	 * as they will be *after* accounting for the free space
 	 * we've used up will need fewer blocks to to represent
 	 * than we've allocated.  We can use the AGFL to hold
-	 * XFS_AGFL_SIZE (128) blocks but that's it.
+	 * XFS_AGFL_SIZE (sector/xfs_agfl_t) blocks but that's it.
 	 * Thus we limit things to XFS_AGFL_SIZE/2 for each of the 2 btrees.
 	 * if the number of extra blocks is more than that,
 	 * we'll have to be called again.
@@ -465,11 +461,9 @@ calculate_freespace_cursor(xfs_mount_t *mp, xfs_agnumber_t agno,
 	 * figure out how many free extents will be used up by
 	 * our space allocation
 	 */
-	if ((ext_ptr = findfirst_bcnt_extent(agno)) == NULL)  {
-		do_error("can't rebuild fs trees -- not enough free space "
-			"on ag %u\n", agno);
-		exit(1);
-	}
+	if ((ext_ptr = findfirst_bcnt_extent(agno)) == NULL)
+		do_error(_("can't rebuild fs trees -- not enough free space "
+			   "on ag %u\n"), agno);
 
 	i = 0;
 	while (ext_ptr != NULL && blocks_needed > 0)  {
@@ -491,11 +485,9 @@ calculate_freespace_cursor(xfs_mount_t *mp, xfs_agnumber_t agno,
 		}
 #endif
 	}
-	if (blocks_needed > 0)  {
-		do_error("ag %u - not enough free space to build freespace "
-			"btrees\n", agno);
-		exit(1);
-	}
+	if (blocks_needed > 0)
+		do_error(_("ag %u - not enough free space to build freespace "
+			   "btrees\n"), agno);
 
 	ASSERT(num_extents >= extents_used);
 
@@ -529,9 +521,9 @@ calculate_freespace_cursor(xfs_mount_t *mp, xfs_agnumber_t agno,
 				 * the old tree had more than one level.
 				 * this is bad.
 				 */
-				 do_warn("not enough free blocks left to "
-					"describe all free blocks in AG %u\n",
-					agno);
+				 do_warn(_("not enough free blocks left to "
+					   "describe all free blocks in AG "
+					   "%u\n"), agno);
 			}
 #ifdef XR_BLD_FREE_TRACE
 			fprintf(stderr,
@@ -779,7 +771,7 @@ build_freespace_tree(xfs_mount_t *mp, xfs_agnumber_t agno,
 	 */
 	if (magic == XFS_ABTB_MAGIC)
 		ext_ptr = findfirst_bno_extent(agno);
-	else 
+	else
 		ext_ptr = findfirst_bcnt_extent(agno);
 
 #ifdef XR_BLD_FREE_TRACE
@@ -1079,7 +1071,7 @@ build_agi(xfs_mount_t *mp, xfs_agnumber_t agno,
 	int		i;
 
 	agi_buf = libxfs_getbuf(mp->m_dev,
-			XFS_AG_DADDR(mp, agno, XFS_AGI_DADDR),
+			XFS_AG_DADDR(mp, agno, XFS_AGI_DADDR(mp)),
 			mp->m_sb.sb_sectsize/BBSIZE);
 	agi = XFS_BUF_TO_AGI(agi_buf);
 	bzero(agi, mp->m_sb.sb_sectsize);
@@ -1258,8 +1250,8 @@ build_agf_agfl(xfs_mount_t	*mp,
 	xfs_agf_t		*agf;
 
 	agf_buf = libxfs_getbuf(mp->m_dev,
-				XFS_AG_DADDR(mp, agno, XFS_AGF_DADDR),
-				mp->m_sb.sb_sectsize/BBSIZE);
+			XFS_AG_DADDR(mp, agno, XFS_AGF_DADDR(mp)),
+			mp->m_sb.sb_sectsize/BBSIZE);
 	agf = XFS_BUF_TO_AGF(agf_buf);
 	bzero(agf, mp->m_sb.sb_sectsize);
 
@@ -1306,7 +1298,7 @@ build_agf_agfl(xfs_mount_t	*mp,
 		 * yes - grab the AGFL buffer
 		 */
 		agfl_buf = libxfs_getbuf(mp->m_dev,
-				XFS_AG_DADDR(mp, agno, XFS_AGFL_DADDR),
+				XFS_AG_DADDR(mp, agno, XFS_AGFL_DADDR(mp)),
 				mp->m_sb.sb_sectsize/BBSIZE);
 		agfl = XFS_BUF_TO_AGFL(agfl_buf);
 		bzero(agfl, mp->m_sb.sb_sectsize);
@@ -1314,13 +1306,13 @@ build_agf_agfl(xfs_mount_t	*mp,
 		 * ok, now grab as many blocks as we can
 		 */
 		i = j = 0;
-		while (bno_bt->num_free_blocks > 0 && i < XFS_AGFL_SIZE)  {
+		while (bno_bt->num_free_blocks > 0 && i < XFS_AGFL_SIZE(mp))  {
 			INT_SET(agfl->agfl_bno[i], ARCH_CONVERT,
 				get_next_blockaddr(agno, 0, bno_bt));
 			i++;
 		}
 
-		while (bcnt_bt->num_free_blocks > 0 && i < XFS_AGFL_SIZE)  {
+		while (bcnt_bt->num_free_blocks > 0 && i < XFS_AGFL_SIZE(mp))  {
 			INT_SET(agfl->agfl_bno[i], ARCH_CONVERT,
 				get_next_blockaddr(agno, 0, bcnt_bt));
 			i++;
@@ -1339,10 +1331,12 @@ build_agf_agfl(xfs_mount_t	*mp,
 
 		if (j > 0)  {
 			if (j == lostblocks)
-				do_warn("lost %d blocks in ag %u\n", j, agno);
+				do_warn(_("lost %d blocks in ag %u\n"),
+					j, agno);
 			else
-				do_warn("thought we were going to lose %d "
-					"blocks in ag %u, actually lost %d\n",
+				do_warn(_("thought we were going to lose %d "
+					  "blocks in ag %u, actually lost "
+					  "%d\n"),
 					lostblocks, j, agno);
 		}
 
@@ -1357,7 +1351,7 @@ build_agf_agfl(xfs_mount_t	*mp,
 		libxfs_writebuf(agfl_buf, 0);
 	} else  {
 		INT_ZERO(agf->agf_flfirst, ARCH_CONVERT);
-		INT_SET(agf->agf_fllast, ARCH_CONVERT, XFS_AGFL_SIZE - 1);
+		INT_SET(agf->agf_fllast, ARCH_CONVERT, XFS_AGFL_SIZE(mp) - 1);
 		INT_ZERO(agf->agf_flcount, ARCH_CONVERT);
 	}
 
@@ -1388,7 +1382,7 @@ sync_sb(xfs_mount_t *mp)
 
 	bp = libxfs_getsb(mp, 0);
 	if (!bp)
-		do_error("couldn't get superblock\n");
+		do_error(_("couldn't get superblock\n"));
 
 	sbp = XFS_BUF_TO_SBP(bp);
 
@@ -1400,7 +1394,7 @@ sync_sb(xfs_mount_t *mp)
 	update_sb_version(mp);
 
 	*sbp = mp->m_sb;
-        libxfs_xlate_sb(XFS_BUF_PTR(bp), sbp, -1, ARCH_CONVERT,
+	libxfs_xlate_sb(XFS_BUF_PTR(bp), sbp, -1, ARCH_CONVERT,
 			XFS_SB_ALL_BITS);
 	libxfs_writebuf(bp, 0);
 }
@@ -1442,7 +1436,7 @@ phase5(xfs_mount_t *mp)
 	extern int	count_bcnt_extents(xfs_agnumber_t);
 #endif
 
-	do_log("Phase 5 - rebuild AG headers and trees...\n");
+	do_log(_("Phase 5 - rebuild AG headers and trees...\n"));
 
 #ifdef XR_BLD_FREE_TRACE
 	fprintf(stderr, "inobt level 1, maxrec = %d, minrec = %d\n",
@@ -1491,8 +1485,9 @@ phase5(xfs_mount_t *mp)
 			 * and clearing the in-use bit in the incore inode
 			 * tree.  Then try mk_incore_fstree() again.
 			 */
-			do_error("unable to rebuild AG %u.  "
-				"Not enough free space in on-disk AG.\n", agno);
+			do_error(_("unable to rebuild AG %u.  "
+				  "Not enough free space in on-disk AG.\n"),
+				agno);
 		}
 
 		/*
@@ -1529,9 +1524,8 @@ phase5(xfs_mount_t *mp)
 			 * and clearing the in-use bit in the incore inode
 			 * tree.  Then try mk_incore_fstree() again.
 			 */
-			do_error("unable to rebuild AG %u.  No free space.\n",
-				agno);
-			exit(1);
+			do_error(
+			_("unable to rebuild AG %u.  No free space.\n"), agno);
 		}
 
 #ifdef XR_BLD_FREE_TRACE
@@ -1553,12 +1547,12 @@ phase5(xfs_mount_t *mp)
 		/*
 		 * see if we can fit all the extra blocks into the AGFL
 		 */
-		extra_blocks = (extra_blocks - XFS_AGFL_SIZE > 0)
-				? extra_blocks - XFS_AGFL_SIZE
+		extra_blocks = (extra_blocks - XFS_AGFL_SIZE(mp) > 0)
+				? extra_blocks - XFS_AGFL_SIZE(mp)
 				: 0;
 
 		if (extra_blocks > 0)  {
-			do_warn("lost %d blocks in agno %d, sorry.\n",
+			do_warn(_("lost %d blocks in agno %d, sorry.\n"),
 				extra_blocks, agno);
 			sb_fdblocks -= extra_blocks;
 		}
@@ -1616,13 +1610,13 @@ phase5(xfs_mount_t *mp)
 
 	if (mp->m_sb.sb_rblocks)  {
 		do_log(
-		"        - generate realtime summary info and bitmap...\n");
+		_("        - generate realtime summary info and bitmap...\n"));
 		rtinit(mp);
 		generate_rtinfo(mp, btmcompute, sumcompute);
 		teardown_rt_bmap(mp);
 	}
 
-	do_log("        - reset superblock...\n");
+	do_log(_("        - reset superblock...\n"));
 
 	/*
 	 * sync superblock counter and set version bits correctly
