@@ -36,6 +36,10 @@
 #include "protos.h"
 #include "err_protos.h"
 
+#define BSIZE	(1024 * 1024)
+
+#define XFS_AG_BYTES(bblog)	((long long)BBSIZE << (bblog))
+#define	XFS_AG_MIN_BYTES	((XFS_AG_BYTES(15)))	/* 16 MB */
 
 /*
  * copy the fields of a superblock that are present in primary and
@@ -90,8 +94,6 @@ copy_sb(xfs_sb_t *source, xfs_sb_t *dest)
 	bzero(source->sb_fname, 12);
 }
 
-#define BSIZE	(1024 * 1024)
-
 /*
  * find a secondary superblock, copy it into the sb buffer
  */
@@ -522,31 +524,6 @@ get_sb(xfs_sb_t *sbp, xfs_off_t off, int size, xfs_agnumber_t agno)
 	return (verify_sb(sbp, 0));
 }
 
-#if 0
-int
-check_growfs(xfs_off_t off, int bufnum, xfs_agnumber_t agnum)
-{
-	int rval;
-
-	ASSERT(bufnum < NUM_SBS);
-
-	/* try and read it first */
-
-	if (lseek64(fs_fd, off, SEEK_SET) != off)
-		return(XR_EOF);
-
-	if ((rval = read(fs_fd, sb_bufs[bufnum], sbbuf_size)) != sbbuf_size)  {
-		/*
-		 * we didn't get a full block so the filesystem
-		 * could not have been grown.  return a non-XR_OK
-		 * result code.
-		 */
-		return(XR_EOF);
-	}
-
-	return(get_sb(off, bufnum, agnum));
-}
-#endif
 /* returns element on list with highest reference count */
 
 fs_geo_list_t *
